<?php
 /**
   * PDF - Impressao com Header
   *
   * @package Sistemas Divulgao Online
   * @author Geandro Bessa
   * @copyleft 2013
   * @version 2
   */
   
  define('_VALID_PHP', true);
  define('FPDF_FONTPATH', 'fpdf/font/');  
  require_once("fpdf/fpdf.php");


//function hex2dec
//returns an associative array (keys: R,G,B) from
//a hex html code (e.g. #3FE5AA)
function hex2dec($couleur = "#000000"){
	$R = substr($couleur, 1, 2);
	$rouge = hexdec($R);
	$V = substr($couleur, 3, 2);
	$vert = hexdec($V);
	$B = substr($couleur, 5, 2);
	$bleu = hexdec($B);
	$tbl_couleur = array();
	$tbl_couleur['R']=$rouge;
	$tbl_couleur['V']=$vert;
	$tbl_couleur['B']=$bleu;
	return $tbl_couleur;
}

//conversion pixel -> millimeter at 72 dpi
function px2mm($px){
	return $px*25.4/72;
}

function txtentities($html){
	$trans = get_html_translation_table(HTML_ENTITIES);
	$trans = array_flip($trans);
	return strtr($html, $trans);
}

class PDF_Impressao extends FPDF
{
	// private variables
	public $tamanho = 0;
	var $is_header = false;
	var $linha1;
	var $linha2;
	var $linha3;
	var $colunas;
	var $format;
	var $angle=0;
	//variables of html parser
	protected $B;
	protected $I;
	protected $U;
	protected $HREF;
	protected $fontList;
	protected $issetfont;
	protected $issetcolor;
	
	function __construct($orientation='P', $unit='mm', $format='A4')
	{
		//Call parent constructor
		parent::__construct($orientation,$unit,$format);
		//Initialization
		$this->B=0;
		$this->I=0;
		$this->U=0;
		$this->HREF='';
		$this->fontlist=array('arial', 'times', 'courier', 'helvetica', 'symbol');
		$this->issetfont=false;
		$this->issetcolor=false;
	}

	// Page header
	function Header()
	{	
		global $is_header, $linha1, $linha2, $linha3;
		
		if($is_header) {
			// Logo
			$this->Image('./assets/img/logo-empresa.png',10,20,60);
			// Arial bold 15
			$this->SetFont('Arial','',10);
			// Move to the right
			$this->Ln(10);
			$this->Cell(0,10,$linha1,0,0,'R');
			$this->Ln(5);
			$this->Cell(0,10,$linha2,0,0,'R');
			$this->Ln(5);
			$this->Cell(0,10,$linha3,0,0,'R');
			// Line break
			$this->Ln(5);
		} else {
			// Line break
			$this->Ln(5);
		}
	}

	// Page footer
	function Footer()
	{
		// Position at 1.5 cm from bottom
		$this->SetY(-16);
		$this->Cell(0,0,'',1,0,'C');
		$this->SetY(-15);
		// Arial italic 8
		$this->SetFont('Arial','I',8);
		// Page number
		$this->Cell(0,10,'SIS.NET - Sistemas de Gesto - Impresso: '.date('d/m/Y H:i:s'),0,0,'L');
		$this->Cell(0,10,'Pgina '.$this->PageNo(),0,0,'R');
	}

	function setHeader( $l1, $l2, $l3 )
	{
		global $is_header, $linha1, $linha2, $linha3;
		
		$is_header = true;
		
		$linha1 = utf8_decode($l1);
		$linha2 = utf8_decode($l2);
		$linha3 = utf8_decode($l3);
	}

	// Titlo
	function titulo( $texto )
	{
		$texto = utf8_decode($texto);
		$this->Ln(5);
		$this->SetFont( "Arial", "", 18);
		$this->Cell(0,35,$texto,0,1,'C');
		$this->SetFont( "Arial", "", $this->tamanho);
	}

	// Assinatura
	function assinatura($nome = '')
	{
		// Position at 1.5 cm from bottom
		$this->Ln(5);
		$this->SetFont('Arial','',$this->tamanho-2);
		$this->Cell(0,45,'__________________________________________________________',0,0,'C');
		$this->SetFont('Arial','B',$this->tamanho-2);
		$this->Ln(10);
		$this->Cell(0,45,$nome,0,1,'C');
	}

	// private functions
	function RoundedRect($x, $y, $w, $h, $r, $style = '')
	{
		$k = $this->k;
		$hp = $this->h;
		if($style=='F')
			$op='f';
		elseif($style=='FD' || $style=='DF')
			$op='B';
		else
			$op='S';
		$MyArc = 4/3 * (sqrt(2) - 1);
		$this->_out(sprintf('%.2F %.2F m',($x+$r)*$k,($hp-$y)*$k ));
		$xc = $x+$w-$r ;
		$yc = $y+$r;
		$this->_out(sprintf('%.2F %.2F l', $xc*$k,($hp-$y)*$k ));

		$this->_Arc($xc + $r*$MyArc, $yc - $r, $xc + $r, $yc - $r*$MyArc, $xc + $r, $yc);
		$xc = $x+$w-$r ;
		$yc = $y+$h-$r;
		$this->_out(sprintf('%.2F %.2F l',($x+$w)*$k,($hp-$yc)*$k));
		$this->_Arc($xc + $r, $yc + $r*$MyArc, $xc + $r*$MyArc, $yc + $r, $xc, $yc + $r);
		$xc = $x+$r ;
		$yc = $y+$h-$r;
		$this->_out(sprintf('%.2F %.2F l',$xc*$k,($hp-($y+$h))*$k));
		$this->_Arc($xc - $r*$MyArc, $yc + $r, $xc - $r, $yc + $r*$MyArc, $xc - $r, $yc);
		$xc = $x+$r ;
		$yc = $y+$r;
		$this->_out(sprintf('%.2F %.2F l',($x)*$k,($hp-$yc)*$k ));
		$this->_Arc($xc - $r, $yc - $r*$MyArc, $xc - $r*$MyArc, $yc - $r, $xc, $yc - $r);
		$this->_out($op);
	}

	function _Arc($x1, $y1, $x2, $y2, $x3, $y3)
	{
		$h = $this->h;
		$this->_out(sprintf('%.2F %.2F %.2F %.2F %.2F %.2F c ', $x1*$this->k, ($h-$y1)*$this->k,
							$x2*$this->k, ($h-$y2)*$this->k, $x3*$this->k, ($h-$y3)*$this->k));
	}

	function Rotate($angle, $x=-1, $y=-1)
	{
		if($x==-1)
			$x=$this->x;
		if($y==-1)
			$y=$this->y;
		if($this->angle!=0)
			$this->_out('Q');
		$this->angle=$angle;
		if($angle!=0)
		{
			$angle*=M_PI/180;
			$c=cos($angle);
			$s=sin($angle);
			$cx=$x*$this->k;
			$cy=($this->h-$y)*$this->k;
			$this->_out(sprintf('q %.5F %.5F %.5F %.5F %.2F %.2F cm 1 0 0 1 %.2F %.2F cm',$c,$s,-$s,$c,$cx,$cy,-$cx,-$cy));
		}
	}

	function _endpage()
	{
		if($this->angle!=0)
		{
			$this->angle=0;
			$this->_out('Q');
		}
		parent::_endpage();
	}

	// public functions
	function sizeOfText( $texte, $largeur)
	{
		$largeur = ($largeur) ? $largeur : 1;
		$index    = 0;
		$nb_lines = 0;
		$loop     = TRUE;
		while ( $loop )
		{
			$pos = strpos($texte, "\n");
			if (!$pos)
			{
				$loop  = FALSE;
				$linha = $texte;
			}
			else
			{
				$linha  = substr( $texte, $index, $pos);
				$texte = substr( $texte, $pos+1 );
			}
			$length = floor( $this->GetStringWidth( $linha ) );
			$res = 1 + floor( $length / $largeur) ;
			$nb_lines += $res;
		}
		return $nb_lines;
	}

	// Empresa
	function addEmpresa( $nom = " ", $adresse = " ")
	{
		$x1 = 10;
		$y1 = 50;
		//Positionnement en bas
		$this->SetXY( $x1, $y1 );
		$this->SetFont('Arial','B',11);
		$length = $this->GetStringWidth( $nom );
		$this->Cell( $length, 2, $nom);
		$this->SetXY( $x1, $y1 + 4 );
		$this->SetFont( "Arial", "", 10);	
		$length = $this->GetStringWidth( $adresse );
		$linhas = $this->sizeOfText( $adresse, $length) ;
		$this->Cell( $length, 2, $adresse);
	}

	// Sub Titulo
	function subtitulo($texto1, $texto2)
	{
		$this->SetFont( "Arial", "B", 10);
		$r1  = $this->w - 80;
		$r2  = $r1 + 68;
		$y1  = 48;
		$y2  = $y1+10;
		$mid = $y1 + (($y2-$y1) / 2);
		$this->RoundedRect($r1, $y1, ($r2 - $r1), ($y2-$y1), 2.5, 'D');
		$this->Line( $r1, $mid, $r2, $mid);
		$this->SetXY( $r1 + 16 , $y1+1 );
		$this->Cell(40, 4, $texto1, '', '', "C");
		$this->SetFont( "Arial", "", 10);
		$this->SetXY( $r1 + 16 , $y1+5 );
		$this->Cell(40, 5, $texto2, '', '', "C");
	}

	function addPageNumber( $page )
	{
		$r1  = $this->w - 80;
		$r2  = $r1 + 19;
		$y1  = 17;
		$y2  = $y1;
		$mid = $y1 + ($y2 / 2);
		$this->RoundedRect($r1, $y1, ($r2 - $r1), $y2, 3.5, 'D');
		$this->Line( $r1, $mid, $r2, $mid);
		$this->SetXY( $r1 + ($r2-$r1)/2 - 5, $y1+3 );
		$this->SetFont( "Arial", "B", $this->tamanho);
		$this->Cell(10,5, "PAGE", 0, 0, "C");
		$this->SetXY( $r1 + ($r2-$r1)/2 - 5, $y1 + 9 );
		$this->SetFont( "Arial", "", $this->tamanho);
		$this->Cell(10,5,$page, 0,0, "C");
	}

	function definirCols( $tab )
	{
		global $colunas;
		$colunas = $tab;
	}

	function addCols( $inicio, $final, $tab )
	{
		$this->SetFont( "Arial", "B", $this->tamanho);	
		$r1  = 10;
		$r2  = $this->w - ($r1 * 2) ;
		$y1  = $inicio;
		$y2  = $final;
		$this->SetXY( $r1, $y1 );
		$this->Rect( $r1, $y1, $r2, $y2, "D");
		$this->Line( $r1, $y1+6, $r1+$r2, $y1+6);
		$colX = $r1;
		while ( list( $lib, $pos ) = each ($tab) )
		{
			$this->SetXY( $colX, $y1+2 );
			$this->Cell( $pos, 1, $lib, 0, 0, "C");
			$colX += $pos;
			$this->Line( $colX, $y1, $colX, $y1+$y2);
		}
		$this->SetFont( "Arial", "", $this->tamanho);	
	}

	function addLineFormat( $tab )
	{
		global $format, $colunas;
		
		while ( list( $lib, $pos ) = each ($colunas) )
		{
			if ( isset( $tab["$lib"] ) )
				$format[ $lib ] = $tab["$lib"];
		}
	}

	// add a line to the invoice/estimate
	/*    $linha = array( "REFERENCE"    => $prod["ref"],
						  "DESIGNATION"  => $libelle,
						  "QUANTITE"     => sprintf( "%.2F", $prod["qte"]) ,
						  "P.U. HT"      => sprintf( "%.2F", $prod["px_unit"]),
						  "MONTANT H.T." => sprintf ( "%.2F", $prod["qte"] * $prod["px_unit"]) ,
						  "TVA"          => $prod["tva"] );
	*/
	function addLine( $linha, $tab, $bold = false )
	{
		
		
		if($bold) {
			$this->SetFont( "Arial", "B", $this->tamanho+1);
		} else {
			$this->SetFont( "Arial", "", $this->tamanho);
		}
		global $colunas, $format;

		$ordonnee     = 10;
		$maxSize      = $linha;

		reset( $colunas );
		while ( list( $lib, $pos ) = each ($colunas) )
		{
			$longCell  = $pos -2;
			$texte     = $tab[ $lib ];
			$length    = $this->GetStringWidth( $texte );
			$tailleTexte = $this->sizeOfText( $texte, $length );
			$formText  = $format[ $lib ];
			$this->SetXY( $ordonnee, $linha-1);
			$this->MultiCell( $longCell, 4 , $texte, 0, $formText);
			if ( $maxSize < ($this->GetY()  ) )
				$maxSize = $this->GetY() ;
			$ordonnee += $pos;
		}
		return ( $maxSize - $linha );
	}

	function minititulo($inicio, $titulo )
	{
		$length = $this->GetStringWidth( $titulo  );
		$r1  = 10;
		$r2  = $length + 5;
		$y1  = $inicio;
		$y2  = $y1+5;
		$this->SetXY( $r1 , $y1 );
		$this->SetFont( "Arial", "B", 12);
		$this->Cell($r2,4, $titulo);
		$this->SetFont( "Arial", "", 10);	
		return $y2;
	}

	function destaques($inicio, $titulo, $texto)
	{
		$length_t = $this->GetStringWidth( $titulo  );
		$length_x = $this->GetStringWidth(  $texto );
		$r1  = 10;
		$r2  = $length_t + 5;
		$r3  = $length_x + 5;
		$y1  = $inicio;
		$y2  = $y1+5;
		$this->SetXY( $r1 , $y1 );
		$this->SetFont( "Arial", "B", 10);
		$this->Cell($r2,4, $titulo.": ");
		$this->SetFont( "Arial", "", 10);	
		$this->Cell($r3, 4, $texto);
		return $y2;
	}

	// add a watermark (temporary estimate, DUPLICATA...)
	// call this method first
	function rascunho( $texto )
	{
		$texto = utf8_decode($texto);
		$this->SetFont('Arial','B',50);
		$this->SetTextColor(203,203,203);
		$this->Rotate(45,55,190);
		$this->Text(55,190,$texto);
		$this->Rotate(0);
		$this->SetTextColor(0,0,0);
	}

	function tamanho( $tamanho )
	{
		$this->tamanho = 10+$tamanho;
	}

	function WriteHTML($html)
	{
		//HTML parser		
		$html=html_entity_decode($html);
		$html=utf8_decode($html);
		$html=strip_tags($html,"<b><u><i><a><img><p><br><strong><em><font><tr><blockquote>"); //supprime tous les tags sauf ceux reconnus
		$html=str_replace("\n",' ',$html); //remplace retour  la ligne par un espace
		$a=preg_split('/<(.*)>/U',$html,-1,PREG_SPLIT_DELIM_CAPTURE); //clate la chane avec les balises
		foreach($a as $i=>$e)
		{
			if($i%2==0)
			{
				//Text
				if($this->HREF)
					$this->PutLink($this->HREF,$e);
				else
					$this->Write(5,stripslashes(txtentities($e)));
			}
			else
			{
				//Tag
				if($e[0]=='/')
					$this->CloseTag(strtoupper(substr($e,1)));
				else
				{
					//Extract attributes
					$a2=explode(' ',$e);
					$tag=strtoupper(array_shift($a2));
					$attr=array();
					foreach($a2 as $v)
					{
						if(preg_match('/([^=]*)=["\']?([^"\']*)/',$v,$a3))
							$attr[strtoupper($a3[1])]=$a3[2];
					}
					$this->OpenTag($tag,$attr);
				}
			}
		}
	}

	function OpenTag($tag, $attr)
	{
		//Opening tag
		switch($tag){
			case 'strong':
				$this->SetStyle('B',true);
				break;
			case 'em':
				$this->SetStyle('I',true);
				break;
			case 'b':
			case 'i':
			case 'u':
				$this->SetStyle($tag,true);
				break;
			case 'a':
				$this->HREF=$attr['href'];
				break;
			case 'img':
				if(isset($attr['src']) && (isset($attr['width']) || isset($attr['height']))) {
					if(!isset($attr['width']))
						$attr['width'] = 0;
					if(!isset($attr['height']))
						$attr['height'] = 0;
					$this->Image($attr['src'], $this->GetX(), $this->GetY(), px2mm($attr['width']), px2mm($attr['height']));
				}
				break;
			case 'tr':
			case 'blockquote':
			case 'br':
				$this->Ln(5);
				break;
			case 'p':
				$this->Ln(10);
				break;
			case 'font':
				if (isset($attr['color']) && $attr['color']!='') {
					$coul=hex2dec($attr['color']);
					$this->SetTextColor($coul['r'],$coul['v'],$coul['b']);
					$this->issetcolor=true;
				}
				if (isset($attr['face']) && in_array(strtolower($attr['face']), $this->fontlist)) {
					$this->SetFont(strtolower($attr['face']));
					$this->issetfont=true;
				}
				break;
		}
	}

	function CloseTag($tag)
	{
		//Closing tag
		if($tag=='strong')
			$tag='b';
		if($tag=='em')
			$tag='i';
		if($tag=='b' || $tag=='i' || $tag=='u')
			$this->SetStyle($tag,false);
		if($tag=='a')
			$this->HREF='';
		if($tag=='font'){
			if ($this->issetcolor==true) {
				$this->SetTextColor(0);
			}
			if ($this->issetfont) {
				$this->SetFont('arial');
				$this->issetfont=false;
			}
		}
	}

	function SetStyle($tag, $enable)
	{
		//Modify style and select corresponding font
		$this->$tag+=($enable ? 1 : -1);
		$style='';
		foreach(array('B','I','U') as $s)
		{
			if($this->$s>0)
				$style.=$s;
		}
		$this->SetFont('',$style);
	}

	function PutLink($URL, $txt)
	{
		//Put a hyperlink
		$this->SetTextColor(0,0,255);
		$this->SetStyle('U',true);
		$this->Write(5,$txt,$URL);
		$this->SetStyle('U',false);
		$this->SetTextColor(0);
	}

}
?>
