<?php
  /**
   * Classe Faturamento
   *
   * @package Sistemas Divulgação Online
   * @author Geandro Bessa
   * @copyright 2013
   * @version 2
   */
  
  if (!defined("_VALID_PHP"))
      die('Acesso direto a esta classe não é permitido.');

  class Faturamento
  {
	  private static $db;

      /**
       * Faturamento::__construct()
       * 
       * @return
       */
      function __construct()
      {
          self::$db = Registry::get("Database");
	  }
   	  
	  /**
       * Faturamento::processarBanco()
       * 
       * @return
       */
      public function processarBanco()
      {
			if (empty($_POST['banco']))
              Filter::$msgs['banco'] = lang('MSG_ERRO_NOME');

			if (empty(Filter::$msgs)) {
              $data = array(
					'id_empresa' => sanitize(post('id_empresa')),
					'banco' => sanitize(post('banco')),
					'codigo' => sanitize(post('codigo')),
					'agencia' => sanitize(post('agencia')),
					'conta' => sanitize(post('conta')),
					'operacao' => sanitize(post('operacao')),
					'saldo' => converteMoeda(post('saldo'))
			  );

              (Filter::$id) ? self::$db->update("banco", $data, "id=" . Filter::$id) : self::$db->insert("banco", $data);
              
			  $message = (Filter::$id) ? lang('BANCO_AlTERADO_OK') : lang('BANCO_ADICIONADO_OK');

              if (self::$db->affected()) {
                  Filter::msgOk($message, "index.php?do=banco&acao=listar");
              } else
                  Filter::msgAlert(lang('NAOPROCESSADO'));
          } else
              print Filter::msgStatus();
      }
	  
	  /**
       * Faturamento::getBancos()
       * 
       * @return
       */
      public function getBancos()
      {		
		  $sql = "SELECT b.id, b.id_empresa, b.banco, b.codigo, b.agencia, b.conta, b.operacao, b.saldo, e.nome " 
		  . "\n FROM banco AS b"
		  . "\n LEFT JOIN empresa AS e ON e.id = b.id_empresa "
		  . "\n WHERE b.inativo = 0 "
		  . "\n ORDER BY b.banco ";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
   	  
	  /**
       * Faturamento::processarTipoPagamento()
       * 
       * @return
       */
      public function processarTipoPagamento()
      {
			if (empty($_POST['tipo']))
              Filter::$msgs['tipo'] = lang('MSG_ERRO_NOME');
		  
			if (empty(Filter::$msgs)) {
			  $parcelas = (is_numeric(post('parcelas')) and post('parcelas') > 0) ? post('parcelas') : 1;
              $data = array(
					'tipo' => sanitize(post('tipo')),
					'dias' => sanitize(post('dias')),
					'id_banco' => sanitize(post('id_banco')),
					'parcelas' => $parcelas,
					'taxa' => converteMoeda(post('taxa')),
					'caixa' => sanitize(post('caixa')),
					'pago' => sanitize(post('pago'))
			  );

              (Filter::$id) ? self::$db->update("tipo_pagamento", $data, "id=" . Filter::$id) : self::$db->insert("tipo_pagamento", $data);
              
			  $message = (Filter::$id) ? lang('FINANCEIRO_PAGAMENTOS_ALTERADO_OK') : lang('FINANCEIRO_PAGAMENTOS_ADICIONADO_OK');

              if (self::$db->affected()) {
                  Filter::msgOk($message, "index.php?do=tipopagamento&acao=listar");
              } else
                  Filter::msgAlert(lang('NAOPROCESSADO'));
          } else
              print Filter::msgStatus();
      }
	  
	  /**
       * Faturamento::getTipoPagamento()
       * 
       * @return
       */
      public function getTipoPagamento()
      {		  
		  $sql = "SELECT t.*, b.banco " 
		  . "\n FROM tipo_pagamento as t"
		  . "\n LEFT JOIN banco as b ON b.id = t.id_banco "
		  . "\n WHERE t.inativo = 0 "
		  . "\n ORDER BY t.tipo ASC ";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Faturamento::processarTranferenciaBanco()
       * 
       * @return
       */
      public function processarTranferenciaBanco()
      {
			if (empty($_POST['id_banco_origem']))
				Filter::$msgs['id_banco_origem'] = lang('MSG_ERRO_BANCO');	
				
			if (empty($_POST['id_banco_destino']))
              Filter::$msgs['id_banco_destino'] = lang('MSG_ERRO_BANCO');
				
			if (empty($_POST['valor']))
              Filter::$msgs['valor'] = lang('MSG_ERRO_VALOR');
		  
		    $id_banco = post('id_banco_origem');
		    $valor = converteMoeda(post('valor'));
			$saldo = $this->getSaldoTotal(false, $id_banco);
			$saldo += 0.01; //Esta entrando na condição de $valor > $saldo quando os valores são iguais
			
			if($valor > $saldo)
              Filter::$msgs['saldo'] = lang('MSG_ERRO_SALDO_TRANSFERENCIA');
		  

		if (empty(Filter::$msgs)) {	
		
			$nome_origem = getValue("banco","banco","id = ".sanitize(post('id_banco_origem')));
			$id_empresa_origem = getValue("id_empresa","banco","id = ".sanitize(post('id_banco_origem')));
			$nome_destino = getValue("banco","banco","id = ".sanitize(post('id_banco_destino')));
			$id_empresa_destino = getValue("id_empresa","banco","id = ".sanitize(post('id_banco_destino')));
			
			$obs = 'TRANSFERENCIA ENTRE BANCO DE '.$nome_origem.' PARA '.$nome_destino;
			
			$data_transferencia = (empty($_POST['data'])) ? date('d/m/Y') : sanitize(post('data'));	
			
            $data_receita = array(	
				'id_empresa' => $id_empresa_destino, 
				'id_banco' => sanitize($_POST['id_banco_destino']),	
				'id_conta' => 117, 
				'descricao' => $obs, 
				'valor' => converteMoeda(post('valor')),	
				'valor_pago' => converteMoeda(post('valor')),		
				'data_vencimento' => dataMySQL($data_transferencia),
				'data_pagamento' => dataMySQL($data_transferencia),
				'pago' => '1',
				'usuario' => $_SESSION['nomeusuario'],
                'data' => "NOW()"
            );
			self::$db->insert("receita", $data_receita);
			  
			$data_despesa = array(
				'id_empresa' => $id_empresa_origem, 
				'id_banco' => sanitize(post('id_banco_origem')),	
				'id_conta' => 118,	
				'descricao' => $obs,	
				'valor' => converteMoeda(post('valor')),		
				'data_vencimento' => dataMySQL($data_transferencia),
				'data_pagamento' => dataMySQL($data_transferencia),
				'pago' => '1',
				'usuario' => $_SESSION['nomeusuario'],
				'data' => "NOW()"
			);
			$id_despesa = self::$db->insert("despesa", $data_despesa);
			$data_update = array(
				'agrupar' => $id_despesa
			);
			self::$db->update("despesa", $data_update, "id=".$id_despesa);
				
            $message = lang('BANCO_TRANSACAO_OK');

            if (self::$db->affected()) {
                Filter::msgOk($message, "index.php?do=banco&acao=listar");	
            } else
				Filter::msgAlert(lang('NAOPROCESSADO'));
		} else
			print Filter::msgStatus();
      }
	  
	  /**
       * Faturamento::processarCreditoBanco()
       * 
       * @return
       */
      public function processarCreditoBanco()
      {
			if (empty($_POST['tipo']))
				Filter::$msgs['tipo'] = lang('MSG_ERRO_TIPO');	
							
			if (empty($_POST['id_banco']))
              Filter::$msgs['id_banco'] = lang('MSG_ERRO_BANCO');
				
			if (empty($_POST['valor']))
              Filter::$msgs['valor'] = lang('MSG_ERRO_VALOR');
				
			if (empty($_POST['id_paciente']) and empty($_POST['id_cadastro']))
              Filter::$msgs['paciente_cadastro'] = lang('MSG_ERRO_CADASTRO_PACIENTE');
				
			if (!empty($_POST['id_paciente']) and !empty($_POST['id_cadastro']))
              Filter::$msgs['paciente_cadastro'] = lang('MSG_ERRO_RECEITA');

		if (empty(Filter::$msgs)) {	
		
			$id_empresa = (empty($_POST['id_empresa'])) ? session('idempresa') : sanitize($_POST['id_empresa']);
			$data_pagamento = (empty($_POST['data_pagamento'])) ? date('d/m/Y') : sanitize(post('data_pagamento'));
			$data = array(	
				'id_empresa' => $id_empresa,	
				'id_banco' => sanitize(post('id_banco')),
				'id_cadastro' => sanitize(post('id_cadastro')),		
				'id_paciente' => sanitize(post('id_paciente')),		
				'descricao' => sanitize(post('descricao')),	
				'id_conta' => sanitize(post('id_conta')),
				'tipo' => sanitize(post('tipo')),	
				'pago' => sanitize(post('pago')),	
				'valor' => converteMoeda(post('valor')),	
				'valor_pago' => converteMoeda(post('valor')),	
				'data_pagamento' => dataMySQL($data_pagamento),
				'data_vencimento' => "NOW()",												
				'pago' => '1',
				'usuario' => session('nomeusuario'),
                'data' => "NOW()"
			);
            self::$db->insert("receita", $data);
            $message = lang('FINANCEIRO_RECEITA_ADICIONADA_OK');

            if (self::$db->affected()) {
                Filter::msgOk($message, "index.php?do=faturamento&acao=receitas");
            } else
				Filter::msgAlert(lang('NAOPROCESSADO'));
		} else
			print Filter::msgStatus();
      }
	  
	  /**
       * Faturamento::processarEntradaCaixa()
       * 
       * @return
       */
      public function processarEntradaCaixa()
      {
			if (empty($_POST['tipo']))
				Filter::$msgs['tipo'] = lang('MSG_ERRO_TIPO');	
							
			if (empty($_POST['valor']))
              Filter::$msgs['valor'] = lang('MSG_ERRO_VALOR');
				
		if (empty(Filter::$msgs)) {	
		
			$data = array(	
				'id_cartoes' => '1',
				'id_empresa' => session('idempresa'),	
				'id_banco' => sanitize(post('id_banco')),	
				'id_paciente' => sanitize(post('id_paciente')),		
				'descricao' => sanitize(post('descricao')),	
				'id_conta' => sanitize(post('id_conta')),
				'tipo' => sanitize(post('tipo')),
				'valor' => converteMoeda(post('valor')),	
				'valor_pago' => converteMoeda(post('valor')),
				'data_caixa' => "NOW()",											
				'data_pagamento' => "NOW()",											
				'data_vencimento' => "NOW()",
				'pago' => '1',
				'usuario_caixa' => session('nomeusuario'),
				'usuario' => session('nomeusuario'),
                'data' => "NOW()"
			);
            self::$db->insert("receita", $data);
            $message = lang('FINANCEIRO_RECEITA_ADICIONADA_OK');

            if (self::$db->affected()) {
                Filter::msgOk($message, "index.php?do=caixa&acao=adicionar");
            } else
				Filter::msgAlert(lang('NAOPROCESSADO'));
		} else
			print Filter::msgStatus();
      }
	  
	  /**
       * Faturamento::editarReceitas()
       * 
       * @return
       */
      public function editarReceitas()
      {				
			if (empty($_POST['descricao']))
              Filter::$msgs['descricao'] = lang('MSG_ERRO_DESCRICAO');

			if (empty(Filter::$msgs)) {			
				
				$id_receita = post('id_receita');
				$id_pagamento = post('id_pagamento');
				$id_empresa = (empty($_POST['id_empresa'])) ? session('idempresa') : sanitize($_POST['id_empresa']);
				$data = array(
					'id_empresa' => $id_empresa,	
					'id_banco' => sanitize(post('id_banco')),	
					'descricao' => sanitize(post('descricao')),	
					'id_conta' => sanitize(post('id_conta')),	
					'tipo' => sanitize(post('tipo')),	
					'pago' => sanitize(post('pago')),
					'valor' => converteMoeda(post('valor')),	
					'valor_pago' => converteMoeda(post('valor_pago')),	
					'data_caixa' => dataMySQL(post('data_pagamento')),	
					'data_pagamento' => dataMySQL(post('data_pagamento')),	
					'data_vencimento' => dataMySQL(post('data_vencimento')),	
					'usuario_caixa' => sanitize(post('usuario_caixa')),
					'usuario' => session('nomeusuario'),
					'data' => "NOW()"
				);
				self::$db->update("receita", $data, "id=".$id_receita);
				  
			  $message = lang('FINANCEIRO_RECEITA_AlTERADO_OK');
			  
			  $redirecionar = "index.php?do=faturamento&acao=receitas";

              if (self::$db->affected()) {
                  Filter::msgOk($message, $redirecionar);
              } else
                  Filter::msgAlert(lang('NAOPROCESSADO'));
          } else
              print Filter::msgStatus();
      }
	  
	  /**
       * Faturamento::processarDataReceita()
       * 
       * @return
       */
      public function processarDataReceita()
      {
			if (empty($_POST['id_banco']))
				Filter::$msgs['id_banco'] = lang('MSG_ERRO_BANCO');	
				
			if (empty($_POST['data_pagamento']))
              Filter::$msgs['data_pagamento'] = lang('MSG_ERRO_DATA');

			if (empty(Filter::$msgs)) {			
				
				$data = array(
					'id_banco' => sanitize(post('id_banco')),
					'id_conta' => sanitize(post('id_conta')),
					'data_pagamento' => dataMySQL($_POST['data_pagamento']),
					'usuario' => session('nomeusuario'),
					'data' => "NOW()"
				);
				if (!empty($_POST['tipo'])) {
					$data['tipo'] = sanitize($_POST['tipo']);
				}
				self::$db->update("receita", $data, "id=".post('id_receita'));
				  
				$message = lang('FINANCEIRO_RECEITA_AlTERADO_OK');
			  
			  
				if (empty($_POST['numero_cartao'])) {
					$redirecionar = "index.php?do=faturamento&acao=receber&id_banco=".$_POST['id_banco']."&dataini=".$_POST['data_pagamento'];
				} else {
					$redirecionar = "index.php?do=faturamento&acao=cartoes&numero_cartao=".$_POST['numero_cartao'];
				}
			  
			  

              if (self::$db->affected()) {
                  Filter::msgOk($message, $redirecionar);
              } else
                  Filter::msgAlert(lang('NAOPROCESSADO'));
          } else
              print Filter::msgStatus();
      }
	  
	  /**
       * Faturamento::getContasReceitas()
       * 
       * @return
       */
      public function getContasReceitas($mes_ano)
      {		  
		 $sql = "SELECT c.id, c.conta" 
		  . "\n FROM receita as p" 
		  . "\n LEFT JOIN conta as c ON c.id = p.id_conta" 
		  . "\n WHERE DATE_FORMAT(p.data_vencimento, '%m/%Y') = '$mes_ano' "
		  . "\n AND p.id_empresa = ".session('idempresa')
		  . "\n GROUP BY c.conta"
		  . "\n ORDER BY c.conta";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }  
	  
	  /**
       * Faturamento::totalPagamentos()
       * 
       * @return
       */
      public function totalPagamentos($consdata = false)
      {		  
          $data = ($consdata) ? $consdata : date("d/m/Y");
		  
		  $sql = "SELECT SUM(valor) as total FROM receita"
		  . "\n WHERE pago = 1 AND DATE_FORMAT(data_vencimento, '%d/%m/%Y') = '$data'"
		  . "\n AND id_empresa = ".session('idempresa');
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      }
	  
	  /**
       * Faturamento::totalPagamentosMes()
       * 
       * @return
       */
      public function totalPagamentosMes($consdata = false, $id_conta = false, $pago = 1)
      {		  
          $data = ($consdata) ? $consdata : date("m/Y");
          $conta = ($id_conta) ? "AND id_conta = '$id_conta'" : "";
		  
		  $sql = "SELECT SUM(valor) as total FROM receita"
		  . "\n WHERE pago = $pago AND DATE_FORMAT(data_vencimento, '%m/%Y') = '$data' $conta"
		  . "\n AND id_empresa = ".session('idempresa');
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      }
	  
	  /**
       * Faturamento::processarConta()
       * 
       * @return
       */
      public function processarConta()
      {
          if (empty($_POST['conta']))
              Filter::$msgs['conta'] = lang('MSG_ERRO_NOME');	  
		  
          if (empty($_POST['tipo']))
              Filter::$msgs['tipo'] = lang('MSG_ERRO_TIPO');	 

          if (empty(Filter::$msgs)) {
			  
			  $tipo = post('tipo');
              if($tipo == 'I') {
					$tipo = 'D';
			  } elseif($tipo == 'DF') {
					$tipo = 'D';
			  } elseif($tipo == 'DV') {
					$tipo = 'D';
			  }
			  $data = array(
				'conta' => sanitize(post('conta')),
				'tipo' => $tipo,
				'classificacao' => sanitize(post('tipo')),
				'contabil' => sanitize(post('contabil')),
				'id_pai' => sanitize(post('id_pai')),
				'ordem' => sanitize(post('ordem')),
				'dre' => sanitize(post('dre'))
			  );
              (Filter::$id) ? self::$db->update("conta", $data, "id=" . Filter::$id) : self::$db->insert("conta", $data);
              $message = (Filter::$id) ? lang('FINANCEIRO_CONTA_AlTERADO_OK') : lang('FINANCEIRO_CONTA_ADICIONADO_OK');

              if (self::$db->affected()) {
                  Filter::msgOk($message, "index.php?do=faturamento&acao=plano_contas");
              } else
                  Filter::msgAlert(lang('NAOPROCESSADO'));
          } else
              print Filter::msgStatus();
      }
	  
	  /**
       * Faturamento::getContas()
       * 
       * @return
       */
      public function getContas()
      {
          $sql = "SELECT filho.id AS id, filho.contabil, pai.conta AS pai, filho.conta as filho, filho.tipo, filho.exibir, filho.dre, filho.ordem, filho.id_pai, filho.classificacao "
		  ."\n FROM conta AS pai "
		  ."\n RIGHT JOIN conta AS filho ON filho.id_pai = pai.id "
		  ."\n WHERE filho.exibir = 1 "
		  ."\n ORDER BY pai.conta, filho.conta";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Faturamento::getPAI()
       * 
       * @return
       */
      public function getPai($tipo = false)
      {
		  $where = ($tipo) ? "AND tipo in ($tipo)" : "";
          $sql = "SELECT id, conta, ordem FROM conta WHERE exibir = 1 AND id_pai IS NULL $where ORDER BY conta";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Faturamento::getFilho()
       * 
       * @return
       */
      public function getFilho($pai)
      {
          $sql = "SELECT c1.conta AS pai, c2.id AS id_filho, c2.conta AS filho FROM conta AS c1 LEFT JOIN conta AS c2 ON c2.id_pai = c1.id WHERE c1.id = '$pai' AND c1.exibir = 1 AND c2.exibir = 1 ORDER BY c2.conta";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }	  
	  
	  /**
       * Faturamento::getReceber()
       * 
       * @return
       */
	  public function getReceber()
      {
		  $sql = "SELECT count(1) AS quant, SUM(p.valor) as valor " 
		  . "\n FROM receita as p" 
		  . "\n WHERE p.pago = 0 AND p.data_vencimento > CURDATE()" 
		  . "\n AND p.id_empresa = ".session('idempresa');
          $row = self::$db->first($sql);

          return ($row) ? $row : 0;
      }  
	  
	  /**
       * Faturamento::getSaldoInicial()
       * 
       * @return
       */
      public function getSaldoInicial($data = false, $id_banco = 0)
      {
		  $data = ($data) ? $data : date('d/m/Y');
		  
		  $sql = "SELECT SUM(valor_pago) as total FROM despesa "
		  . "\n WHERE id_banco = '$id_banco' AND pago = 1 AND inativo = 0 AND data_vencimento < STR_TO_DATE('$data 00:00:00','%d/%m/%Y %H:%i:%s')";		  
		  $row = self::$db->first($sql);
		  
		  $despesa = ($row) ? $row->total : 0;
		  
		  
		  $sql = "SELECT SUM(valor_pago) as total FROM receita "
		  . "\n WHERE id_banco = '$id_banco' AND pago = 1 AND inativo = 0 AND data_pagamento < STR_TO_DATE('$data 00:00:00','%d/%m/%Y %H:%i:%s')";	
		  $row = self::$db->first($sql);		  
		  
		  $receita = ($row) ? $row->total : 0;
		  
		  $sql = "SELECT saldo FROM banco"
		  . "\n WHERE inativo = 0 "
		  . "\n AND id = $id_banco";
		  $row = self::$db->first($sql);
		  
		  $saldo = ($row) ? $row->saldo : 0;

          return $saldo + $receita - $despesa;
      }
	  
	  /**
       * Faturamento::getSaldoTotal()
       * 
       * @return
       */
      public function getSaldoTotal($data = false, $id_banco = 0)
      {
		  $data = ($data) ? $data : date('d/m/Y');
		  
		  $sql = "SELECT SUM(valor_pago) as total FROM despesa "
		  . "\n WHERE id_banco = '$id_banco' AND pago = 1 AND inativo = 0 AND data_vencimento < STR_TO_DATE('$data 23:59:59','%d/%m/%Y %H:%i:%s')";		  
		  $row = self::$db->first($sql);
		  
		  $despesa = ($row) ? $row->total : 0;
		  
		  
		  $sql = "SELECT SUM(valor_pago) as total FROM receita "
		  . "\n WHERE id_banco = '$id_banco' AND pago = 1 AND inativo = 0 AND data_pagamento < STR_TO_DATE('$data 23:59:59','%d/%m/%Y %H:%i:%s')";	
		  $row = self::$db->first($sql);		  
		  
		  $receita = ($row) ? $row->total : 0;
		  
		  $sql = "SELECT saldo FROM banco"
		  . "\n WHERE inativo = 0 "
		  . "\n AND id = $id_banco";
		  $row = self::$db->first($sql);
		  
		  $saldo = ($row) ? $row->saldo : 0;

          return $saldo + $receita - $despesa;
      }
	  
	  /**
       * Faturamento::getMovimentoCaixaData()
	   *
       * @return
       */
	  public function getMovimentoCaixaData($data)
      {
         $sql = "SELECT f.id, p.nome as paciente, f.id_atendimento, f.valor_pago, t.tipo as pagamento " 
		  . "\n FROM paciente_financeiro as f "
		  . "\n LEFT JOIN paciente as p ON p.id = f.id_paciente "
		  . "\n LEFT JOIN tipo_pagamento as t ON t.id = f.tipo "
		  . "\n WHERE f.inativo = 0 AND t.caixa = 1 AND DATE_FORMAT(f.data_caixa, '%d/%m/%Y') = '$data' "
		  . "\n AND f.id_empresa = ".session('idempresa')
		  . "\n ORDER BY f.id ";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Faturamento::getMovimentoCaixaDataContratos()
	   *
       * @return
       */
	  public function getMovimentoCaixaDataContratos($data)
      {
         $sql = "SELECT f.id, p.nome as paciente, f.id_contrato, f.valor_pago, t.tipo as pagamento " 
		  . "\n FROM paciente_financeiro as f "
		  . "\n LEFT JOIN paciente as p ON p.id = f.id_paciente "
		  . "\n LEFT JOIN tipo_pagamento as t ON t.id = f.tipo "
		  . "\n WHERE f.inativo = 0 AND t.caixa = 1 AND f.id_contrato > 0 AND DATE_FORMAT(f.data_caixa, '%d/%m/%Y') = '$data' "
		  . "\n AND f.id_empresa = ".session('idempresa')
		  . "\n ORDER BY f.id ";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Faturamento::getFinanceiroCaixaData()
	   *
       * @return
       */
	  public function getFinanceiroCaixaData($data)
      {
         $sql = "SELECT t.id, t.tipo as pagamento, SUM(f.valor_pago) AS valor_pago " 
		  . "\n FROM paciente_financeiro as f "
		  . "\n LEFT JOIN tipo_pagamento as t ON t.id = f.tipo "
		  . "\n WHERE DATE_FORMAT(f.data_caixa, '%d/%m/%Y') = '$data' AND f.inativo = 0 AND t.caixa = 1 "
		  . "\n AND f.id_empresa = ".session('idempresa')
		  . "\n GROUP BY t.id DESC"
		  . "\n ORDER BY t.id ";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Faturamento::getCaixaAberturaData()
	   *
       * @return
       */
	  public function getCaixaAberturaData($data)
      {
         $sql = "SELECT SUM(f.valor_pago) AS valor_pago " 
		  . "\n FROM paciente_financeiro as f "
		  . "\n WHERE DATE_FORMAT(f.data_caixa, '%d/%m/%Y') = '$data' AND f.inativo = 0 AND f.tipo = 1 AND f.id_paciente = 0 "
		  . "\n AND f.id_empresa = ".session('idempresa');
          $row = self::$db->first($sql);

          return ($row) ? $row->valor_pago : 0;
      }
	  
	  /**
       * Faturamento::totalCreditoBanco()
       * 
       * @return
       */
      public function totalCreditoBanco($id_banco)
      {		  
	  
		  $sql = "SELECT SUM(valor_pago) as total FROM receita "
		  . "\n WHERE id_banco = '$id_banco' AND pago = 1 AND inativo = 0"
		  . "\n AND id_empresa = ".session('idempresa');
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      }
	  
	  /**
       * Faturamento::getFaturamentoParcelas()
       * 
       * @return
       */
      public function getFaturamentoReceitas($mes_ano = 0)
      {
		 $sql = "SELECT SUM(r.valor_pago) AS total " 
		  . "\n FROM receita as r " 
		  . "\n WHERE DATE_FORMAT(r.data_vencimento, '%m/%Y') = '$mes_ano' "
		  . "\n AND r.id_empresa = ".session('idempresa');
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      } 
	  
      /**
       * Faturamento::processarMetaDRE()
       * 
       * @return
       */
      public function processarMetaDRE()
      {		  
		  if (empty($_POST['id_conta']))
              Filter::$msgs['id_conta'] = lang('MSG_ERRO_CONTA');	 
			  
		  if (empty($_POST['mes_ano']))
              Filter::$msgs['mes_ano'] = lang('MSG_ERRO_DATA');	 

          if (empty(Filter::$msgs)) {
			  
              $mes_ano = $_POST['mes_ano'];
			  
              if(strlen($mes_ano) > 9) {
				$mes_ano = substr($mes_ano, 3);
			  }
			  $ano = explode("/", $mes_ano);
			  $id_conta = $_POST['id_conta'];
			  self::$db->delete("conta_meta", "id_conta = $id_conta AND DATE_FORMAT(mes_ano, '%m/%Y') = '$mes_ano'");
              $mes_ano = "01/".$mes_ano;
			  
			  $data = array(
					'id_conta' => sanitize($_POST['id_conta']), 
					'mes_ano' => dataMySQL($mes_ano),
					'meta' => converteMoeda($_POST['valor']),
					'usuario' => session('nomeusuario'),
					'data' => "NOW()"
			  );
			  
              self::$db->insert("conta_meta", $data);
              $message = lang('META_ADICIONADO_OK');

              if (self::$db->affected()) {			  
                  Filter::msgOk($message, "index.php?do=faturamento&acao=metasdre&ano=".$ano[1]);    
              } else
                  Filter::msgAlert(lang('NAOPROCESSADO'));
          } else
              print Filter::msgStatus();
      }

      /**
       * Faturamento::getMetas()
       * 
       * @return
       */
      public function getMetasDRE($mes_ano, $id_conta)
      {
		  $sql = "SELECT SUM(meta) as total FROM conta_meta WHERE id_conta = $id_conta AND DATE_FORMAT(mes_ano, '%m/%Y') = '$mes_ano' ";
          $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      }
	  
	  /**
       * Faturamento::getReceitaDinheiro()
       * 
       * @return
       */
      public function getReceitaDinheiro($mes_ano = 0)
      {
		 $sql = "SELECT SUM(r.valor_pago) AS total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN conta as c ON c.id = r.id_conta " 
		  . "\n WHERE r.inativo = 0 AND r.pago = 1 AND c.exibir = 1 AND c.dre = 1 AND c.exibir = 1 AND r.tipo = 1 AND DATE_FORMAT(r.data_pagamento, '%m/%Y') = '$mes_ano' "
		  . "\n AND r.id_empresa = ".session('idempresa');
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      } 
	  
	  /**
       * Faturamento::getReceitaCheque()
       * 
       * @return
       */
      public function getReceitaCheque($mes_ano = 0)
      {	
		 $sql = "SELECT SUM(r.valor_pago) AS total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN conta as c ON c.id = r.id_conta " 
		  . "\n WHERE r.inativo = 0 AND r.pago = 1 AND c.exibir = 1 AND c.dre = 1 AND c.exibir = 1 AND r.tipo = 2 AND DATE_FORMAT(r.data_pagamento, '%m/%Y') = '$mes_ano' "
		  . "\n AND r.id_empresa = ".session('idempresa');
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      } 
	  
	  /**
       * Faturamento::getReceitaDeposito()
       * 
       * @return
       */
      public function getReceitaDeposito($mes_ano = 0)
      {	
		 $sql = "SELECT SUM(r.valor_pago) AS total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN conta as c ON c.id = r.id_conta " 
		  . "\n WHERE r.inativo = 0 AND r.pago = 1 AND c.exibir = 1 AND c.dre = 1 AND c.exibir = 1 AND r.tipo = 3 AND DATE_FORMAT(r.data_pagamento, '%m/%Y') = '$mes_ano' "
		  . "\n AND r.id_empresa = ".session('idempresa');
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      } 
	  
	  /**
       * Faturamento::getReceitaDebito()
       * 
       * @return
       */
      public function getReceitaDebito($mes_ano = 0)
      {		  
		 
		 $sql = "SELECT SUM(r.valor_pago) AS total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN conta as c ON c.id = r.id_conta " 
		  . "\n WHERE r.inativo = 0 AND r.pago = 1 AND c.exibir = 1 AND c.dre = 1 AND c.exibir = 1 AND r.tipo in (5, 9, 12, 13, 23) AND DATE_FORMAT(r.data_pagamento, '%m/%Y') = '$mes_ano' "
		  . "\n AND r.id_empresa = ".session('idempresa');
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      } 
	  
	  /**
       * Faturamento::getReceitaCredito()
       * 
       * @return
       */
      public function getReceitaCredito($mes_ano = 0)
      {		  
		 
		 $sql = "SELECT SUM(r.valor_pago) AS total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN conta as c ON c.id = r.id_conta " 
		  . "\n WHERE r.inativo = 0 AND r.pago = 1 AND c.exibir = 1 AND c.dre = 1 AND c.exibir = 1 AND r.tipo in (4, 6, 8, 16, 22, 10, 11, 14, 15, 17, 18, 19, 20, 24, 25) AND DATE_FORMAT(r.data_pagamento, '%m/%Y') = '$mes_ano' "
		  . "\n AND r.id_empresa = ".session('idempresa');
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      } 
	  
	  /**
       * Faturamento::getReceitaDeposito()
       * 
       * @return
       */
      public function getReceitaTransferencia($mes_ano = 0)
      {		  
		 
		 $sql = "SELECT SUM(r.valor_pago) AS total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN conta as c ON c.id = r.id_conta " 
		  . "\n WHERE r.inativo = 0 AND r.pago = 1 AND c.exibir = 1 AND c.dre = 1 AND c.exibir = 1 AND r.tipo = 0 AND DATE_FORMAT(r.data_pagamento, '%m/%Y') = '$mes_ano' "
		  . "\n AND r.id_empresa = ".session('idempresa');
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      } 
	  
	  /**
       * Faturamento::getCheques()
       * 
       * @return
       */
      public function getCheques()
      {		  
		 $sql = "SELECT f.id, c.conta, cl.nome as cadastro, f.id_banco, b.banco, f.tipo, f.id_cadastro, f.id_paciente, p.nome as paciente, f.valor_pago, f.conciliado, f.data_pagamento, f.data_vencimento, f.pago, DATE_FORMAT(f.data_pagamento, '%Y%m%d') as controle, f.data_pagamento < CURDATE() as atrasado, f.data_pagamento = CURDATE() as hoje " 
		  . "\n FROM receita as f" 
		  . "\n LEFT JOIN conta as c ON c.id = f.id_conta" 
		  . "\n LEFT JOIN cadastro as cl ON cl.id = f.id_cadastro"
		  . "\n LEFT JOIN banco as b ON b.id = f.id_banco" 
		  . "\n LEFT JOIN paciente as p ON p.id = f.id_paciente" 
		  . "\n WHERE f.inativo = 0 AND f.tipo = 2 "
		  . "\n AND f.id_empresa = ".session('idempresa')
		  . "\n ORDER BY f.data_pagamento";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
	} 
	  
	  /**
       * Faturamento::getReceitas()
       * 
       * @return
       */
      public function getReceitas($dataini = false, $datafim = false, $id_banco = false)
      {
          $dataini = ($dataini) ? $dataini : date('d/m/Y', strtotime('-15 days')); 
          $datafim = ($datafim) ? $datafim : date("d/m/Y");
		  $where = "AND f.data_vencimento BETWEEN STR_TO_DATE('$dataini 00:00:00','%d/%m/%Y %H:%i:%s') AND STR_TO_DATE('$datafim 23:59:59','%d/%m/%Y %H:%i:%s')";
		  $wherebanco = ($id_banco) ? "AND f.id_banco = $id_banco" : "";
		  
		  $sql = "SELECT f.id, c.conta, f.id_conta, f.id_banco, b.banco, f.descricao, f.tipo, f.id_paciente, f.id_cadastro, f.valor,  f.valor_pago, f.conciliado, f.data_pagamento, f.data_vencimento, f.pago, t.tipo as pagamento, DATE_FORMAT(f.data_pagamento, '%Y%m%d') as controle, ca.nome as cadastro, p.nome as paciente " 
		  . "\n FROM receita as f" 
		  . "\n LEFT JOIN conta as c ON c.id = f.id_conta" 
		  . "\n LEFT JOIN tipo_pagamento as t ON t.id = f.tipo" 
		  . "\n LEFT JOIN banco as b ON b.id = f.id_banco" 
		  . "\n LEFT JOIN cadastro as ca ON ca.id = f.id_cadastro" 
		  . "\n LEFT JOIN paciente as p ON p.id = f.id_paciente" 
		  . "\n WHERE f.inativo = 0 AND f.pago = 0 AND f.id_empresa = ".session('idempresa')
		  . "\n $where"
		  . "\n $wherebanco"
		  . "\n ORDER BY f.data_pagamento";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
	} 
	  
	  /**
       * Faturamento::getReceitasPagas()
       * 
       * @return
       */
      public function getReceitasPagas($dataini = false, $datafim = false, $id_banco = false)
      {
          $dataini = ($dataini) ? $dataini : date('d/m/Y', strtotime('-15 days')); 
          $datafim = ($datafim) ? $datafim : date("d/m/Y");
		  $where = "AND f.data_pagamento BETWEEN STR_TO_DATE('$dataini 00:00:00','%d/%m/%Y %H:%i:%s') AND STR_TO_DATE('$datafim 23:59:59','%d/%m/%Y %H:%i:%s')";
		  $wherebanco = ($id_banco) ? "AND f.id_banco = $id_banco" : "";
		  
		  $sql = "SELECT f.id, c.conta, f.id_conta, f.id_banco, b.banco, f.descricao, f.tipo, f.id_paciente, f.id_cadastro, f.valor,  f.valor_pago, f.conciliado, f.data_pagamento, f.data_vencimento, f.pago, t.tipo as pagamento, DATE_FORMAT(f.data_pagamento, '%Y%m%d') as controle, ca.nome as cadastro, p.nome as paciente " 
		  . "\n FROM receita as f" 
		  . "\n LEFT JOIN conta as c ON c.id = f.id_conta" 
		  . "\n LEFT JOIN tipo_pagamento as t ON t.id = f.tipo" 
		  . "\n LEFT JOIN banco as b ON b.id = f.id_banco" 
		  . "\n LEFT JOIN cadastro as ca ON ca.id = f.id_cadastro" 
		  . "\n LEFT JOIN paciente as p ON p.id = f.id_paciente" 
		  . "\n WHERE f.inativo = 0 AND f.pago = 1 AND f.id_empresa = ".session('idempresa')
		  . "\n $where"
		  . "\n $wherebanco"
		  . "\n ORDER BY f.data_pagamento";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
	} 
	
	  /**
       * Faturamento::getReceitaOutros()
       * 
       * @return
       */
      public function getReceitaOutros($mes_ano)
      {	
		 $sql = "SELECT SUM(r.valor_pago) AS total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN conta as c ON c.id = r.id_conta " 
		  . "\n WHERE r.inativo = 0 AND r.pago = 1 AND c.exibir = 1 AND c.dre = 1 AND c.exibir = 1 AND r.tipo > 3 AND DATE_FORMAT(r.data_pagamento, '%m/%Y') = '$mes_ano' "
		  . "\n AND r.id_empresa = ".session('idempresa');
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      } 
	  
	  /**
       * Faturamento::getDREMes()
       * 
       * @return
       */
      public function getDREMes($mes_ano = 0, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? " AND r.id_empresa = $id_empresa " : "";
		  $sql = "SELECT c.id, c.id_pai, p.conta AS conta_pai, c.conta, SUM(r.valor_pago) as total " 
		  . "\n FROM conta AS c" 
		  . "\n LEFT JOIN conta AS p ON p.id = c.id_pai" 
		  . "\n LEFT JOIN receita AS r ON c.id = r.id_conta AND r.inativo = 0 " 
		  . "\n 	AND r.pago = 1 " 
		  . "\n 	AND DATE_FORMAT(r.data_pagamento, '%m/%Y') = '$mes_ano' "
		  . "\n 	$wempresa "
		  . "\n WHERE  c.id_pai IS NOT NULL AND c.tipo = 'C' AND p.dre = 1 AND c.dre = 1 AND p.exibir = 1 AND c.exibir = 1 " 
		  . "\n GROUP BY c.id_pai , c.id " 
		  . "\n ORDER BY p.ordem, p.conta, c.ordem, c.conta ASC ";
		  
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
	  } 
	  
	  /**
       * Faturamento::getContasDRE()
       * 
       * @return
       */
      public function getContasDRE()
      {
		  
		  $sql = "SELECT c.id, c.id_pai, p.conta AS conta_pai, c.conta " 
		  . "\n FROM conta AS c" 
		  . "\n LEFT JOIN conta AS p ON p.id = c.id_pai" 
		  . "\n WHERE c.exibir = 1 AND c.id_pai IS NOT NULL AND c.tipo = 'C' AND p.dre = 1 AND c.dre = 1 AND p.exibir = 1 AND c.exibir = 1 " 
		  . "\n ORDER BY p.ordem, c.ordem, p.conta , c.conta ASC ";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
	}
	  
	  /**
       * Faturamento::getDetalhesReceitas()
       * 
       * @return
       */
      public function getDetalhesReceitas($id_receita = 0)
      {		  
		  $sql = "SELECT f.id, c.conta, f.id_conta, f.id_banco, b.banco, f.descricao, f.tipo, f.id_cadastro, f.valor, f.valor_pago, f.conciliado, f.data_pagamento, f.data_vencimento, f.pago, t.tipo as pagamento, DATE_FORMAT(f.data_vencimento, '%Y%m%d') as controle, e.nome as empresa, ca.nome as cadastro,  f.id_empresa, f.inativo, f.pago, f.id_paciente, p.nome as paciente, f.id_pagamento, f.usuario, f.usuario_caixa, f.data_caixa, f.data " 
		  . "\n FROM receita as f" 
		  . "\n LEFT JOIN conta as c ON c.id = f.id_conta" 
		  . "\n LEFT JOIN tipo_pagamento as t ON t.id = f.tipo" 
		  . "\n LEFT JOIN banco as b ON b.id = f.id_banco" 
		  . "\n LEFT JOIN empresa as e ON e.id = f.id_empresa" 
		  . "\n LEFT JOIN cadastro as ca ON ca.id = f.id_cadastro" 
		  . "\n LEFT JOIN paciente as p ON p.id = f.id_paciente "
		  . "\n WHERE f.id = '$id_receita' ";
		  $row = self::$db->first($sql);

          return ($row) ? $row : 0;
	} 
	  
	  /**
       * Faturamento::getCaixasMovimento()
       * 
       * @return
       */
      public function getCaixasMovimento($data)
      {
		 $sql = "SELECT f.tipo as id_tipo, t.tipo, f.valor, f.valor_pago, f.data_vencimento, f.data_pagamento, p.nome, f.usuario, f.pago " 
		  . "\n FROM paciente_financeiro as f " 
		  . "\n LEFT JOIN tipo_pagamento as t ON t.id = f.tipo"
		  . "\n LEFT JOIN paciente as p ON p.id = f.id_paciente "
		  . "\n WHERE f.inativo = 0 AND t.caixa = 1 AND DATE_FORMAT(f.data_caixa, '%d/%m/%Y') = '$data'" 
		  . "\n AND f.id_empresa = ".session('idempresa')
		  . "\n ORDER BY p.nome ";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      } 
	  
	  /**
       * Faturamento::getCaixasReceitaData()
       * 
       * @return
       */
      public function getCaixasReceitaData($data, $id_empresa)
      {
		 $sql = "SELECT r.tipo as id_tipo, t.tipo, r.descricao, r.valor, r.valor_pago, r.data_vencimento, r.data_pagamento, r.data_caixa, p.nome, r.usuario, r.pago, r.inativo, c.nome as convenio, ta.procedimento, a.data_agenda " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN tipo_pagamento as t ON t.id = r.tipo"
		  . "\n LEFT JOIN paciente as p ON p.id = r.id_paciente "
		  . "\n LEFT JOIN atendimento as a ON a.id = r.id_atendimento "
		  . "\n LEFT JOIN cadastro as c ON c.id = a.id_convenio "
		  . "\n LEFT JOIN tabela AS ta ON ta.id = a.id_tabela "
		  . "\n WHERE DATE_FORMAT(r.data_caixa, '%d/%m/%Y') = '$data' " 
		  . "\n AND t.caixa = 1 AND r.id_empresa = '$id_empresa' "
		  . "\n ORDER BY r.tipo, p.nome ";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      } 
	  
	  /**
       * Faturamento::getResumoConvenioData()
       * 
       * @return
       */
      public function getResumoConvenioData($data, $id_empresa)
      {
		  $sql = "SELECT SUM(a.valor_pago) AS valor, COUNT(1) AS quant, c.nome as convenio, a.id_convenio " 
		  . "\n FROM atendimento as a " 
		  . "\n LEFT JOIN cadastro as c ON c.id = a.id_convenio "
		  . "\n WHERE a.realizado < 9 AND DATE_FORMAT(a.data_agenda, '%d/%m/%Y') = '$data' " 
		  . "\n AND a.id_empresa = '$id_empresa' AND a.usuario_pagamento like 'convenio%' "
		  . "\n GROUP BY a.id_convenio "
		  . "\n ORDER BY c.nome ";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      } 
	  
	  /**
       * Faturamento::getResumoConvenioMes()
       * 
       * @return
       */
      public function getResumoConvenioMes($data, $id_empresa)
      {
		  $sql = "SELECT SUM(a.valor_pago) AS valor, COUNT(1) AS quant, c.nome as convenio, a.id_convenio " 
		  . "\n FROM atendimento as a " 
		  . "\n LEFT JOIN cadastro as c ON c.id = a.id_convenio "
		  . "\n WHERE a.realizado < 9 AND DATE_FORMAT(a.data_agenda, '%m/%Y') = '$data' " 
		  . "\n AND a.id_empresa = '$id_empresa' AND a.usuario_pagamento like 'convenio%' "
		  . "\n GROUP BY a.id_convenio "
		  . "\n ORDER BY c.nome ";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      } 
	  
	  /**
       * Faturamento::getCaixasConvenioData()
       * 
       * @return
       */
      public function getCaixasConvenioData($data, $id_empresa, $nomeusuario = false)
      {
		 $where = ($nomeusuario) ? " AND a.usuario_guia = '$nomeusuario'" : "";
		 $sql = "SELECT a.*, p.nome, c.nome as convenio, ta.procedimento, u.nome AS medico " 
		  . "\n FROM atendimento as a " 
		  . "\n LEFT JOIN paciente as p ON p.id = a.id_paciente "
		  . "\n LEFT JOIN cadastro as c ON c.id = a.id_convenio "
		  . "\n LEFT JOIN tabela AS ta ON ta.id = a.id_tabela "
		  . "\n LEFT JOIN usuario AS u ON u.id = a.id_medico "
		  . "\n WHERE a.realizado < 9 AND DATE_FORMAT(a.data_agenda, '%d/%m/%Y') = '$data' " 
		  . "\n AND a.id_empresa = '$id_empresa' AND a.usuario_pagamento like 'convenio%' $where "
		  . "\n ORDER BY c.nome, ta.procedimento, p.nome";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      } 
	  
	  /**
       * Faturamento::getCaixasReceita()
       * 
       * @return
       */
      public function getCaixasReceita($data, $nomeusuario)
      {
		 $sql = "SELECT r.tipo as id_tipo, t.tipo, r.descricao, r.valor, r.valor_pago, r.data_vencimento, r.data_pagamento, r.data_caixa, p.nome, r.usuario, r.pago, r.inativo, c.nome as convenio, ta.procedimento, a.data_agenda, r.id_cartoes, u.nome AS medico " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN tipo_pagamento as t ON t.id = r.tipo"
		  . "\n LEFT JOIN paciente as p ON p.id = r.id_paciente "
		  . "\n LEFT JOIN atendimento as a ON a.id = r.id_atendimento "
		  . "\n LEFT JOIN cadastro as c ON c.id = a.id_convenio "
		  . "\n LEFT JOIN tabela AS ta ON ta.id = a.id_tabela "
		  . "\n LEFT JOIN usuario AS u ON u.id = a.id_medico "
		  . "\n WHERE DATE_FORMAT(r.data_caixa, '%d/%m/%Y') = '$data' AND r.usuario_caixa = '$nomeusuario' " 
		  . "\n AND t.caixa = 1 "
		  . "\n ORDER BY p.nome ";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      } 
	  
	  /**
       * Faturamento::getCaixasTotalMovimento()
       * 
       * @return
       */
      public function getCaixasTotalMovimento($data)
      {
		 $sql = "SELECT f.tipo as id_tipo, t.tipo, SUM(f.valor) as valor_total, SUM(f.valor_pago) as valor_pago " 
		  . "\n FROM paciente_financeiro as f " 
		  . "\n LEFT JOIN tipo_pagamento as t ON t.id = f.tipo"
		  . "\n WHERE f.inativo = 0 AND t.caixa = 1 AND DATE_FORMAT(f.data_caixa, '%d/%m/%Y') = '$data'" 
		  . "\n GROUP BY t.tipo "
		  . "\n ORDER BY t.tipo ";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      } 
	  
	  /**
       * Faturamento::getCaixasEntradaReceita()
       * 
       * @return
       */
      public function getCaixasEntradaReceita($data, $nomeusuario)
      {
		 $sql = "SELECT SUM(r.valor_pago) as valor_total " 
		  . "\n FROM receita as r " 
		  . "\n WHERE r.inativo = 0 AND r.id_cartoes = 1 AND DATE_FORMAT(r.data_caixa, '%d/%m/%Y') = '$data' AND r.usuario_caixa = '$nomeusuario'" ;
          $row = self::$db->first($sql);

          return ($row) ? $row->valor_total : 0;
      }
	  
	  /**
       * Faturamento::getCaixasTotalReceita()
       * 
       * @return
       */
      public function getCaixasTotalReceita($data, $nomeusuario)
      {
		 $sql = "SELECT r.tipo as id_tipo, t.tipo, SUM(r.valor_pago) as valor_total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN tipo_pagamento as t ON t.id = r.tipo"
		  . "\n WHERE r.inativo = 0 AND t.caixa = 1 AND DATE_FORMAT(r.data_caixa, '%d/%m/%Y') = '$data' AND r.usuario_caixa = '$nomeusuario'" 
		  . "\n GROUP BY t.tipo "
		  . "\n ORDER BY t.tipo";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Faturamento::getListaReceitasDRE()
       * 
       * @return
       */
      public function getListaReceitasDRE($id_conta, $mes, $ano, $id_empresa = 0)
      {		  
		 $wempresa = ($id_empresa) ? "AND f.id_empresa = $id_empresa " : "";
		 $sql = "SELECT f.id, c.conta, f.id_conta, f.id_banco, b.banco, f.descricao, f.tipo, f.id_cadastro, f.valor,  f.valor_pago, f.linha, f.conciliado, f.data_pagamento, f.data_vencimento, f.pago, f.enviado, t.tipo as pagamento, DATE_FORMAT(f.data_pagamento, '%Y%m%d') as controle, e.nome as empresa, e.sigla, ca.nome as cadastro, f.id_empresa, p.nome AS paciente " 
		  . "\n FROM receita as f" 
		  . "\n LEFT JOIN conta as c ON c.id = f.id_conta" 
		  . "\n LEFT JOIN tipo_pagamento as t ON t.id = f.tipo" 
		  . "\n LEFT JOIN banco as b ON b.id = f.id_banco" 
		  . "\n LEFT JOIN empresa as e ON e.id = f.id_empresa" 
		  . "\n LEFT JOIN cadastro as ca ON ca.id = f.id_cadastro" 
		  . "\n LEFT JOIN paciente as p ON p.id = f.id_paciente" 
		  . "\n WHERE f.inativo = 0 AND f.pago = 1 $wempresa "
		  . "\n AND f.id_conta = $id_conta "
		  . "\n AND MONTH(f.data_pagamento) = $mes "
		  . "\n AND YEAR(f.data_pagamento) = $ano "
		  . "\n ORDER BY f.data_pagamento";
		  //echo $sql;
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
	} 
	  
	  /**
       * Faturamento::getListaReceitasDRE()
       * 
       * @return
       */
      public function getListaFaturamentoDRE($id_conta, $mes, $ano, $id_empresa = 0)
      {		  
		 $wempresa = ($id_empresa) ? "AND f.id_empresa = $id_empresa " : "";
		 $sql = "SELECT f.*, c.conta, t.tipo as pagamento, DATE_FORMAT(f.data_pagamento, '%Y%m%d') as controle, e.nome as empresa, e.sigla, f.id_empresa, p.nome AS paciente, b.banco " 
		  . "\n FROM paciente_financeiro as f" 
		  . "\n LEFT JOIN conta as c ON c.id = f.id_conta" 
		  . "\n LEFT JOIN tipo_pagamento as t ON t.id = f.tipo" 
		  . "\n LEFT JOIN empresa as e ON e.id = f.id_empresa" 
		  . "\n LEFT JOIN paciente as p ON p.id = f.id_paciente" 
		  . "\n LEFT JOIN banco as b ON b.id = f.id_banco" 
		  . "\n WHERE f.inativo = 0 $wempresa "
		  . "\n AND f.id_conta = $id_conta "
		  . "\n AND MONTH(f.data_pagamento) = $mes "
		  . "\n AND YEAR(f.data_pagamento) = $ano "
		  . "\n ORDER BY f.data_pagamento";
		  // echo $sql;
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
	} 
	  
  }
?>