<?php
  /**
   * Classe Gestao
   *
   * @package Sistemas Divulgao Online
   * @author Geandro Bessa
   * @copyright 2013
   * @version 2
   */
  
  if (!defined("_VALID_PHP"))
      die('Acesso direto a esta classe no  permitido.');

  class Gestao
  {
	  private static $db;

      /**
       * Gestao::__construct()
       * 
       * @return
       */
      function __construct()
      {
          self::$db = Registry::get("Database");
      }
	  
	  /**
       * Gestao::getListaAno()
       * 
       * @return
       */
      public function getListaAno($tabela, $campo = "data", $ordem = "ASC", $todos = false)
      {		  
		  $wtodos = ($todos) ? "" : " AND $campo < CURDATE() ";
		 $sql = "SELECT DATE_FORMAT($campo, '%Y') as mes_ano" 
		  . "\n FROM $tabela" 
		  . "\n WHERE DATE_FORMAT($campo, '%Y') <> '0000' $wtodos "
		  . "\n GROUP BY mes_ano"
		  . "\n ORDER BY $campo $ordem ";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getListaAnoTodos()
       * 
       * @return
       */
      public function getListaAnoTodos($tabela, $campo = "data", $ordem = "ASC")
      {	
		 $sql = "SELECT DATE_FORMAT($campo, '%Y') as mes_ano" 
		  . "\n FROM $tabela" 
		  . "\n WHERE $campo < DATE_ADD(CURDATE(), INTERVAL 10 DAY) AND DATE_FORMAT($campo, '%Y') <> '0000' "
		  . "\n GROUP BY mes_ano"
		  . "\n ORDER BY $campo $ordem ";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getListaMes()
       * 
       * @return
       */
      public function getListaMes($tabela, $campo = "data", $where = "", $ordem = "ASC")
      {		  
		  $sql = "SELECT DATE_FORMAT($campo, '%m/%Y') as mes_ano" 
		  . "\n FROM $tabela" 
		  . "\n WHERE $campo < DATE_ADD(CURDATE(), INTERVAL 10 DAY) AND DATE_FORMAT($campo, '%m/%Y') <> '00/0000' $where "
		  . "\n GROUP BY mes_ano"
		  . "\n ORDER BY $campo $ordem ";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getMeses()
       * 
       * @return
       */
      public function getMeses()
      {		  
		  $sql = "SELECT IF(id < 10, CONCAT(0, id), id) AS id, mes, dias " 
		  . "\n FROM meses "
		  . "\n ORDER BY id";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getEnderecos()
       * 
       * @return
       */
      public function getEnderecos()
      {	
		 $sql = "SELECT id, endereco, bairro, cidade, estado, cep " 
		  . "\n FROM cadastro" 
		  . "\n WHERE mapa = 0 limit 500";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getCidades()
       * 
       * @return
       */
      public function getCidades()
      {	
		 $sql = "SELECT id, endereco, bairro, cidade, estado, cep " 
		  . "\n FROM cadastro " 
		  . "\n WHERE inativo = 0 AND cidade = '' and cep <> '' ";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getMapa()
       * 
       * @return
       */
      public function getMapa()
      {	
		 $sql = "SELECT id, nome, lat, lng " 
		  . "\n FROM cadastro" 
		  . "\n WHERE mapa = 1";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Faturamento::getCaixasTotalReceita()
       * 
       * @return
       */
      public function getCaixasTotalReceita($data, $id_empresa)
      {
		 $sql = "SELECT r.tipo as id_tipo, t.tipo, SUM(r.valor_pago) as valor_total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN tipo_pagamento as t ON t.id = r.tipo"
		  . "\n WHERE r.inativo = 0 AND t.caixa = 1 AND r.valor_pago > 0 AND r.id_empresa = '$id_empresa' AND DATE_FORMAT(r.data_caixa, '%m/%Y') = '$data'" 
		  . "\n GROUP BY t.tipo "
		  . "\n ORDER BY t.tipo";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      } 
	  
	  /**
       * Faturamento::getCaixasTotalReceitaDiario()
       * 
       * @return
       */
      public function getCaixasTotalReceitaDiario($data, $id_empresa)
      {
		 $sql = "SELECT r.tipo as id_tipo, t.tipo, SUM(r.valor_pago) as valor_total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN tipo_pagamento as t ON t.id = r.tipo"
		  . "\n WHERE r.inativo = 0 AND t.caixa = 1 AND r.valor_pago > 0 AND r.id_empresa = '$id_empresa' AND DATE_FORMAT(r.data_caixa, '%d/%m/%Y') = '$data'" 
		  . "\n GROUP BY t.tipo "
		  . "\n ORDER BY t.tipo";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      } 
	  
	  /**
       * Gestao::getCaixaTotalRetirada()
	   *
       * @return
       */
	  public function getCaixaTotalRetirada($data, $id_empresa)
      {
         $sql = "SELECT SUM(f.valor_pago) AS valor_total" 
		  . "\n FROM despesa as f" 
		  . "\n WHERE DATE_FORMAT(f.data_caixa, '%m/%Y') = '$data' AND f.id_empresa = '$id_empresa' AND f.inativo = 0 AND f.id_caixa = 1 AND f.pago = 1 ";
          $row = self::$db->first($sql);

          return ($row) ? $row->valor_total : 0;
      }
	  
	  /**
       * Gestao::getCaixaTotalRetiradaDiario()
	   *
       * @return
       */
	  public function getCaixaTotalRetiradaDiario($data, $id_empresa)
      {
         $sql = "SELECT SUM(f.valor_pago) AS valor_total" 
		  . "\n FROM despesa as f" 
		  . "\n WHERE DATE_FORMAT(f.data_caixa, '%d/%m/%Y') = '$data' AND f.id_empresa = '$id_empresa' AND f.inativo = 0 AND f.id_caixa = 1 AND f.pago = 1 ";
          $row = self::$db->first($sql);

          return ($row) ? $row->valor_total : 0;
      }
	  
	  /**
       * Gestao::getAtendimentos()
	   *
       * @return
       */
	  public function getAtendimentos($data, $id_empresa)
      {
         $sql = "SELECT SUM(a.valor_pago) AS valor_tabela, SUM(a.valor_repasse) AS valor_repasse, COUNT(1) AS quant" 
		  . "\n FROM atendimento as a" 
		  . "\n WHERE a.id_empresa = '$id_empresa' AND DATE_FORMAT(a.data_agenda, '%m/%Y') = '$data' AND a.realizado < 9 AND a.bloqueio = 0 ";
          $row = self::$db->first($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getAtendimentosDiario()
	   *
       * @return
       */
	  public function getAtendimentosDiario($data, $id_empresa)
      {
         $sql = "SELECT SUM(a.valor_pago) AS valor_tabela, SUM(a.valor_repasse) AS valor_repasse, COUNT(1) AS quant" 
		  . "\n FROM atendimento as a" 
		  . "\n WHERE a.id_empresa = '$id_empresa' AND DATE_FORMAT(a.data_agenda, '%d/%m/%Y') = '$data' AND a.realizado < 9 AND a.bloqueio = 0 ";
          $row = self::$db->first($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getAtendimentosDiarioPago()
	   *
       * @return
       */
	  public function getAtendimentosDiarioPago($data, $id_empresa = false)
      {
		 $wempresa = ($id_empresa) ? "AND a.id_empresa = $id_empresa" : "";
         $sql = "SELECT SUM(a.valor_pago) AS valor, COUNT(1) AS quant" 
		  . "\n FROM atendimento as a" 
		  . "\n WHERE DATE_FORMAT(a.data_agenda, '%d/%m/%Y') = '$data' AND a.realizado < 9 AND a.bloqueio = 0 AND a.guia = 0 AND a.pago = 1 $wempresa ";
          $row = self::$db->first($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getAtendimentosDiarioPagoParcial()
	   *
       * @return
       */
	  public function getAtendimentosDiarioPagoParcial($data, $id_empresa = false)
      {
		 $wempresa = ($id_empresa) ? "AND a.id_empresa = $id_empresa" : "";
         $sql = "SELECT SUM(a.valor_tabela-a.valor_pago) AS valor, COUNT(1) AS quant" 
		  . "\n FROM atendimento as a" 
		  . "\n WHERE DATE_FORMAT(a.data_agenda, '%d/%m/%Y') = '$data' AND a.realizado < 9 AND a.bloqueio = 0 AND a.guia = 0 AND a.pago = 2 $wempresa ";
          $row = self::$db->first($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getAtendimentosDiarioNaoPago()
	   *
       * @return
       */
	  public function getAtendimentosDiarioNaoPago($data, $id_empresa = false)
      {
		 $wempresa = ($id_empresa) ? "AND a.id_empresa = $id_empresa" : "";
         $sql = "SELECT SUM(IF(a.valor_tabela > 0, a.valor_tabela, IF(a.id_convenio > 0, c.valor_convenio, t.valor))) AS valor, COUNT(1) AS quant" 
		  . "\n FROM atendimento as a" 
		  . "\n LEFT JOIN tabela AS t ON t.id = a.id_tabela "
		  . "\n LEFT JOIN tabela_convenio AS c ON c.id_tabela = a.id_tabela AND c.id_cadastro = a.id_convenio "
		  . "\n WHERE DATE_FORMAT(a.data_agenda, '%d/%m/%Y') = '$data' AND a.realizado < 9 AND a.bloqueio = 0 AND a.guia = 0 AND a.pago = 0 $wempresa ";
          $row = self::$db->first($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getResumoAtendimentosDiario()
	   *
       * @return
       */
	  public function getResumoAtendimentosDiario($data, $id_empresa)
      {
         $sql = "SELECT SUM(IF(a.valor_tabela > 0, a.valor_tabela, IF(a.id_convenio > 0, c.valor_convenio, t.valor))) AS valor, COUNT(1) AS quant, a.realizado" 
		  . "\n FROM atendimento as a" 
		  . "\n LEFT JOIN tabela AS t ON t.id = a.id_tabela "
		  . "\n LEFT JOIN tabela_convenio AS c ON c.id_tabela = a.id_tabela AND c.id_cadastro = a.id_convenio "
		  . "\n WHERE a.id_empresa = '$id_empresa' AND DATE_FORMAT(a.data_agenda, '%d/%m/%Y') = '$data' AND a.realizado < 9 AND a.bloqueio = 0 "
		  . "\n GROUP BY a.realizado"
		  . "\n ORDER BY a.realizado" ;
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getAtendimentosMensal()
	   *
       * @return
       */
	  public function getAtendimentosMensal($data, $id_empresa = false)
      {
		 $wempresa = ($id_empresa) ? "AND a.id_empresa = $id_empresa" : "";
         $sql = "SELECT SUM(a.valor_pago) AS valor_tabela, SUM(a.valor_repasse) AS valor_repasse, COUNT(1) AS quant" 
		  . "\n FROM atendimento as a" 
		  . "\n WHERE DATE_FORMAT(a.data_agenda, '%m/%Y') = '$data' AND a.realizado < 9 AND a.bloqueio = 0 $wempresa ";
          $row = self::$db->first($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getAtendimentosMensalPago()
	   *
       * @return
       */
	  public function getAtendimentosMensalPago($data, $id_empresa = false)
      {
		 $wempresa = ($id_empresa) ? "AND a.id_empresa = $id_empresa" : "";
         $sql = "SELECT SUM(a.valor_pago) AS valor, COUNT(1) AS quant" 
		  . "\n FROM atendimento as a" 
		  . "\n WHERE DATE_FORMAT(a.data_agenda, '%m/%Y') = '$data' AND a.realizado < 9 AND a.bloqueio = 0 AND a.guia = 0 AND a.pago = 1 $wempresa ";
          $row = self::$db->first($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getAtendimentosMensalPagoParcial()
	   *
       * @return
       */
	  public function getAtendimentosMensalPagoParcial($data, $id_empresa = false)
      {
		 $wempresa = ($id_empresa) ? "AND a.id_empresa = $id_empresa" : "";
         $sql = "SELECT SUM(a.valor_tabela-a.valor_pago) AS valor, COUNT(1) AS quant" 
		  . "\n FROM atendimento as a" 
		  . "\n WHERE DATE_FORMAT(a.data_agenda, '%m/%Y') = '$data' AND a.realizado < 9 AND a.bloqueio = 0 AND a.guia = 0 AND a.pago = 2 $wempresa ";
          $row = self::$db->first($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getAtendimentosMensalNaoPago()
	   *
       * @return
       */
	  public function getAtendimentosMensalNaoPago($data, $id_empresa = false)
      {
		 $wempresa = ($id_empresa) ? "AND a.id_empresa = $id_empresa" : "";
         $sql = "SELECT SUM(IF(a.valor_tabela > 0, a.valor_tabela, IF(a.id_convenio > 0, c.valor_convenio, t.valor))) AS valor, COUNT(1) AS quant" 
		  . "\n FROM atendimento as a" 
		  . "\n LEFT JOIN tabela AS t ON t.id = a.id_tabela "
		  . "\n LEFT JOIN tabela_convenio AS c ON c.id_tabela = a.id_tabela AND c.id_cadastro = a.id_convenio "
		  . "\n WHERE DATE_FORMAT(a.data_agenda, '%m/%Y') = '$data' AND a.realizado < 9 AND a.bloqueio = 0 AND a.guia = 0 AND a.pago = 0 $wempresa ";
          $row = self::$db->first($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getResumoAtendimentosMensal()
	   *
       * @return
       */
	  public function getResumoAtendimentosMensal($data, $id_empresa)
      {
         $sql = "SELECT SUM(IF(a.valor_tabela > 0, a.valor_tabela, IF(a.id_convenio > 0, c.valor_convenio, t.valor))) AS valor, COUNT(1) AS quant, a.realizado" 
		  . "\n FROM atendimento as a" 
		  . "\n LEFT JOIN tabela AS t ON t.id = a.id_tabela "
		  . "\n LEFT JOIN tabela_convenio AS c ON c.id_tabela = a.id_tabela AND c.id_cadastro = a.id_convenio "
		  . "\n WHERE a.id_empresa = '$id_empresa' AND DATE_FORMAT(a.data_agenda, '%m/%Y') = '$data' AND a.realizado < 9 AND a.bloqueio = 0"
		  . "\n GROUP BY a.realizado"
		  . "\n ORDER BY a.realizado" ;
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getConvenios()
	   *
       * @return
       */
	  public function getConvenios($data, $id_empresa = false)
      {
		 $wempresa = ($id_empresa) ? "AND a.id_empresa = $id_empresa" : "";
         $sql = "SELECT SUM(IF(a.valor_tabela > 0, a.valor_tabela, IF(a.id_convenio > 0, c.valor_convenio, t.valor))) AS valor_tabela, COUNT(1) AS quant, SUM(a.valor_repasse) AS valor_repasse, ca.nome, a.id_convenio"
		  . "\n FROM atendimento as a" 
		  . "\n LEFT JOIN tabela AS t ON t.id = a.id_tabela "
		  . "\n LEFT JOIN tabela_convenio AS c ON c.id_tabela = a.id_tabela AND c.id_cadastro = a.id_convenio "
		  . "\n LEFT JOIN cadastro as ca on ca.id = a.id_convenio" 
		  . "\n WHERE DATE_FORMAT(a.data_agenda, '%m/%Y') = '$data' AND a.realizado < 9 AND a.bloqueio = 0 AND a.bloqueio = 0 $wempresa "
		  . "\n GROUP BY a.id_convenio" 
		  . "\n ORDER BY ca.nome" ;
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getColaboradores()
	   *
       * @return
       */
	  public function getColaboradores($data, $id_empresa = false)
      {
		 $wempresa = ($id_empresa) ? "AND a.id_empresa = $id_empresa" : "";
          $sql = "SELECT SUM(IF(a.valor_tabela > 0, a.valor_tabela, IF(a.id_convenio > 0, c.valor_convenio, t.valor))) AS valor_tabela, COUNT(1) AS quant, SUM(a.valor_repasse) AS valor_repasse, u.nome, a.id_medico"
		  . "\n FROM atendimento as a" 
		  . "\n LEFT JOIN tabela AS t ON t.id = a.id_tabela "
		  . "\n LEFT JOIN tabela_convenio AS c ON c.id_tabela = a.id_tabela AND c.id_cadastro = a.id_convenio "
		  . "\n LEFT JOIN usuario as u on u.id = a.id_medico" 
		  . "\n WHERE DATE_FORMAT(a.data_agenda, '%m/%Y') = '$data' AND a.realizado = 1 $wempresa "
		  . "\n GROUP BY a.id_medico" 
		  . "\n ORDER BY u.nome" ;
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getColaboradoresDiario()
	   *
       * @return
       */
	  public function getColaboradoresDiario($data, $id_empresa)
      {
         $sql = "SELECT SUM(IF(a.valor_tabela > 0, a.valor_tabela, IF(a.id_convenio > 0, c.valor_convenio, t.valor))) AS valor_tabela, COUNT(1) AS quant, SUM(a.valor_repasse) AS valor_repasse, u.nome"
		  . "\n FROM atendimento as a" 
		  . "\n LEFT JOIN tabela AS t ON t.id = a.id_tabela "
		  . "\n LEFT JOIN tabela_convenio AS c ON c.id_tabela = a.id_tabela AND c.id_cadastro = a.id_convenio "
		  . "\n LEFT JOIN usuario as u on u.id = a.id_medico" 
		  . "\n WHERE DATE_FORMAT(a.data_agenda, '%d/%m/%Y') = '$data' AND a.id_empresa = '$id_empresa' AND a.realizado = 1 "
		  . "\n GROUP BY a.id_medico" 
		  . "\n ORDER BY u.nome" ;
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getProcedimentos()
	   *
       * @return
       */
	  public function getProcedimentos($data, $id_empresa = false, $id_especialidade = false)
      {
		 $wespecialidade = ($id_especialidade) ? "AND t.id_especialidade = $id_especialidade" : "";
		 $wempresa = ($id_empresa) ? "AND a.id_empresa = $id_empresa" : "";		  
         $sql = "SELECT SUM(IF(a.valor_tabela > 0, a.valor_tabela, IF(a.id_convenio > 0, c.valor_convenio, t.valor))) AS valor_tabela, COUNT(1) AS quant, a.id_tabela, t.procedimento, e.nome as especialidade, SUM(a.valor_repasse) AS valor_repasse"
		  . "\n FROM atendimento as a"
		  . "\n LEFT JOIN tabela AS t ON t.id = a.id_tabela "
		  . "\n LEFT JOIN especialidade as e on e.id = t.id_especialidade" 
		  . "\n LEFT JOIN tabela_convenio AS c ON c.id_tabela = a.id_tabela AND c.id_cadastro = a.id_convenio "
		  . "\n WHERE DATE_FORMAT(a.data_agenda, '%m/%Y') = '$data' AND a.realizado = 1 $wempresa $wespecialidade "
		  . "\n GROUP BY a.id_tabela" 
		  . "\n ORDER BY t.procedimento" ;
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getAtendimentosDia()
	   *
       * @return
       */
	  public function getAtendimentosDia($data, $id_empresa)
      {
         $sql = "SELECT SUM(IF(a.valor_tabela > 0, a.valor_tabela, IF(a.id_convenio > 0, c.valor_convenio, t.valor))) AS valor_tabela, COUNT(1) AS quant, DATE_FORMAT(a.data_agenda, '%d/%m/%Y') AS data"
		  . "\n FROM atendimento as a"
		  . "\n LEFT JOIN tabela AS t ON t.id = a.id_tabela "
		  . "\n LEFT JOIN tabela_convenio AS c ON c.id_tabela = a.id_tabela AND c.id_cadastro = a.id_convenio "
		  . "\n WHERE DATE_FORMAT(a.data_agenda, '%m/%Y') = '$data' AND a.id_empresa = '$id_empresa' AND a.realizado < 9 AND a.bloqueio = 0 AND a.bloqueio = 0 "
		  . "\n GROUP BY DATE_FORMAT(a.data_agenda, '%d/%m/%Y')" 
		  . "\n ORDER BY a.data_agenda" ;
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Faturamento::getCaixasReceitaDia()
       * 
       * @return
       */
      public function getCaixasReceitaDia($data, $id_empresa)
      {
		 $sql = "SELECT DATE_FORMAT(r.data_caixa, '%d/%m/%Y') AS data, COUNT(1) AS quant, SUM(r.valor_pago) as valor_pago " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN tipo_pagamento as t ON t.id = r.tipo"
		  . "\n WHERE r.inativo = 0 AND t.caixa = 1 AND r.valor_pago > 0 AND r.id_empresa = '$id_empresa' AND DATE_FORMAT(r.data_caixa, '%m/%Y') = '$data'" 
		  . "\n GROUP BY DATE_FORMAT(r.data_caixa, '%d/%m/%Y')" 
		  . "\n ORDER BY r.data_caixa" ;
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      } 
	  
	  /**
       * Gestao::getCaixasUsuarioDiario()
       * 
       * @return
       */
      public function getCaixasUsuarioDiario($data, $id_empresa)
      {
		 $sql = "SELECT r.usuario_caixa, SUM(r.valor_pago) as valor_total " 
		  . "\n FROM receita as r "
		  . "\n LEFT JOIN tipo_pagamento as t ON t.id = r.tipo"
		  . "\n WHERE r.inativo = 0 AND t.caixa = 1 AND DATE_FORMAT(r.data_caixa, '%d/%m/%Y') = '$data'" 
		  . "\n AND r.id_empresa = '$id_empresa' "
		  . "\n GROUP BY r.usuario_caixa "
		  . "\n ORDER BY r.usuario_caixa";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getCaixaUsuarioRetirada()
	   *
       * @return
       */
	  public function getCaixaUsuarioRetirada($data, $nomeusuario, $id_empresa)
      {
         $sql = "SELECT SUM(f.valor_pago) AS valor_total" 
		  . "\n FROM despesa as f" 
		  . "\n WHERE DATE_FORMAT(f.data_caixa, '%d/%m/%Y') = '$data' AND f.usuario_caixa = '$nomeusuario' AND f.inativo = 0  AND f.pago = 1 "
		  . "\n AND f.id_empresa = 'id_empresa' ";
          $row = self::$db->first($sql);

          return ($row) ? $row->valor_total : 0;
      }

	  /**
       * ************************************* INICIO DE FUNES PARA DASHBOARD *************************************
       */
	  
	  /**
       * Gestao::getFaturado()
	   *
       * @return
       */
	  public function getFaturado($mes_ano = 0, $id_empresa = false)
      {		  
		 $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		 $sql = "SELECT SUM(r.valor_pago) AS total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN conta as c ON c.id = r.id_conta " 
		  . "\n WHERE r.inativo = 0 AND r.pago = 1 AND c.exibir = 1 AND c.dre = 1 AND DATE_FORMAT(r.data_vencimento, '%m/%Y') = '$mes_ano' $wempresa ";
          $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      }
	  
	  /**
       * Gestao::getRecebido()
	   *
       * @return
       */
	  public function getRecebido($mes_ano = 0, $id_empresa = false)
      {		  
		 $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		 $sql = "SELECT SUM(r.valor_pago) AS total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN conta as c ON c.id = r.id_conta " 
		  . "\n WHERE r.inativo = 0 AND r.pago = 1 AND c.exibir = 1 AND c.dre = 1 AND DATE_FORMAT(r.data_pagamento, '%m/%Y') = '$mes_ano' $wempresa ";
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      }
	  
	  /**
       * Gestao::getReceber()
	   *
       * @return
       */
	  public function getReceber($mes_ano = 0, $id_empresa = false)
      {		  
		 $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		 $sql = "SELECT SUM(r.valor_pago) AS total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN conta as c ON c.id = r.id_conta " 
		  . "\n WHERE r.tipo <> 4 AND r.inativo = 0 AND r.pago = 0 AND c.exibir = 1 AND c.dre = 1 AND DATE_FORMAT(r.data_vencimento, '%m/%Y') = '$mes_ano' $wempresa ";
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      }
	  
	  /**
       * Gestao::getReceitas()
       * 
       * @return
       */
      public function getReceitas($mes_ano = 0, $id_empresa = false)
      {		  
		 $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		 $sql = "SELECT SUM(r.valor_pago) AS total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN conta as c ON c.id = r.id_conta " 
		  . "\n WHERE r.tipo <> 4 AND r.inativo = 0 AND r.pago = 1 AND c.exibir = 1 AND c.dre = 1 AND DATE_FORMAT(r.data_pagamento, '%m/%Y') = '$mes_ano' $wempresa ";
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      } 
	  
	  /**
       * Gestao::getReceitasConvenio()
       * 
       * @return
       */
      public function getReceitasConvenio($mes_ano = 0, $id_empresa = false)
      {		  
		 $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		 $sql = "SELECT SUM(r.valor_pago) AS total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN conta as c ON c.id = r.id_conta " 
		  . "\n WHERE r.tipo = 4 AND r.inativo = 0 AND r.pago = 1 AND c.exibir = 1 AND c.dre = 1 AND DATE_FORMAT(r.data_pagamento, '%m/%Y') = '$mes_ano' $wempresa ";
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      } 
	  
	  /**
       * Gestao::getReceitasConvenioPagar()
       * 
       * @return
       */
      public function getReceitasConvenioPagar($id_empresa = false)
      {		  
		 $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		 $sql = "SELECT SUM(r.valor_pago) AS total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN conta as c ON c.id = r.id_conta " 
		  . "\n WHERE r.tipo = 4 AND r.inativo = 0 AND r.pago = 0 AND c.exibir = 1 AND c.dre = 1 $wempresa ";
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      } 
	  
	  /**
       * Gestao::getReceitasConvenioPagarMes()
       * 
       * @return
       */
      public function getReceitasConvenioPagarMes($mes_ano = 0, $id_empresa = false)
      {		  
		 $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		 $sql = "SELECT SUM(r.valor_pago) AS total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN conta as c ON c.id = r.id_conta " 
		  . "\n WHERE r.tipo = 4 AND r.inativo = 0 AND r.pago = 0 AND c.exibir = 1 AND c.dre = 1 AND DATE_FORMAT(r.data_vencimento, '%m/%Y') = '$mes_ano' $wempresa ";
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      } 
	  
	  /**
       * Gestao::getDespesasPagas()
       * 
       * @return
       */
      public function getDespesasPagas($mes_ano = 0, $id_empresa = false)
      {		  
		 $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		 $sql = "SELECT SUM(d.valor) AS total " 
		  . "\n FROM despesa as d" 
		  . "\n LEFT JOIN conta as c ON c.id = d.id_conta " 
		  . "\n WHERE d.inativo = 0 AND d.pago = 1 AND c.exibir = 1 AND c.dre = 1 AND DATE_FORMAT(d.data_pagamento, '%m/%Y') = '$mes_ano' $wempresa ";
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      } 
	  /**
       * Gestao::getFaturadoDia()
	   *
       * @return
       */
	  public function getFaturadoDia($dia = 0, $id_empresa = false)
      {		  
		 $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		 $sql = "SELECT SUM(r.valor) AS total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN conta as c ON c.id = r.id_conta " 
		  . "\n WHERE inativo = 0 AND pago = 1 AND c.exibir = 1 AND c.dre = 1 AND DATE_FORMAT(r.data_vencimento, '%d/%m/%Y') = '$dia' $wempresa ";
          $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      }
	  
	  /**
       * Gestao::getReceitasDia()
       * 
       * @return
       */
      public function getReceitasDia($dia = 0, $id_empresa = false)
      {		  
		 $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		 $sql = "SELECT SUM(r.valor_pago) AS total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN conta as c ON c.id = r.id_conta " 
		  . "\n WHERE r.inativo = 0 AND r.pago = 1 AND c.exibir = 1 AND c.dre = 1 AND DATE_FORMAT(r.data_pagamento, '%d/%m/%Y') = '$dia' $wempresa ";
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      } 
	  
	  /**
       * Gestao::getReceberDia()
       * 
       * @return
       */
      public function getReceberDia($dia = 0, $id_empresa = false)
      {		  
		 $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		 $sql = "SELECT SUM(r.valor_pago) AS total " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN conta as c ON c.id = r.id_conta " 
		  . "\n WHERE r.inativo = 0 AND r.pago = 0 AND c.exibir = 1 AND c.dre = 1 AND DATE_FORMAT(r.data_vencimento, '%d/%m/%Y') = '$dia' $wempresa ";
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      } 
	  
	  /**
       * Gestao::getDespesasPagas()
       * 
       * @return
       */
      public function getDespesasPagasDia($dia = 0, $id_empresa = false)
      {		  
		 $wempresa = ($id_empresa) ? "AND d.id_empresa = $id_empresa" : "";
		 $sql = "SELECT SUM(valor) AS total " 
		  . "\n FROM despesa as d" 
		  . "\n LEFT JOIN conta as c ON c.id = d.id_conta " 
		  . "\n WHERE d.inativo = 0 AND d.pago = 1 AND c.exibir = 1 AND c.dre = 1 AND DATE_FORMAT(d.data_pagamento, '%d/%m/%Y') = '$dia' $wempresa ";
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      } 
	  
	  /**
       * Gestao::getDespesas()
       * 
       * @return
       */
      public function getDespesas($mes_ano = 0, $id_empresa = false)
      {		  
		 $wempresa = ($id_empresa) ? "AND d.id_empresa = $id_empresa" : "";
		 $sql = "SELECT SUM(d.valor) AS total " 
		  . "\n FROM despesa as d" 
		  . "\n LEFT JOIN conta as c ON c.id = d.id_conta " 
		  . "\n WHERE d.inativo = 0 AND c.exibir = 1 AND c.dre = 1 AND DATE_FORMAT(d.data_vencimento, '%m/%Y') = '$mes_ano'  $wempresa";
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      } 
	  
	  /**
       * Gestao::tipoDespesas()
       * 
       * @return
       */
      public function tipoDespesas($ano = false, $mes = false, $id_empresa = false)
      {		  
		  $wempresa = ($id_empresa) ? "AND d.id_empresa = $id_empresa" : "";
		  $wano = ($ano) ? "AND year(data_pagamento) = '$ano'" : "";
		  $wmes = ($mes) ? "AND DATE_FORMAT(data_pagamento, '%m/%Y') = '$mes'" : "";
		  $sql = "SELECT pai.conta, SUM(valor) as valor" 
		  . "\n FROM despesa as d" 
		  . "\n LEFT JOIN conta as c on c.id = d.id_conta" 
		  . "\n LEFT JOIN conta as pai on pai.id = c.id_pai" 
		  . "\n WHERE pago = 1 AND inativo = 0  $wano $wmes $wempresa"
		  . "\n GROUP BY pai.conta";
		  $row = self::$db->fetch_all($sql);
		  
          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::tipoReceitas()
       * 
       * @return
       */
      public function tipoReceitas($ano = false, $mes = false, $id_empresa = false)
      {		  
		 $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		 $wano = ($ano) ? "AND year(data_pagamento) = '$ano'" : "";
		 $wmes = ($mes) ? "AND DATE_FORMAT(data_pagamento, '%m/%Y') = '$mes'" : "";
		 $sql = "SELECT t.tipo, SUM(r.valor_pago) AS valor " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN tipo_pagamento as t on t.id = r.tipo" 
		  . "\n WHERE r.inativo = 0 AND r.pago = 1 $wano $wmes $wempresa"
		  . "\n GROUP BY t.tipo";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      } 
	  
	  /**
       * Gestao::tipoFaturamento()
       * 
       * @return
       */
      public function tipoFaturamento($ano = false, $mes = false, $id_empresa = false)
      {		  
		 $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		 $wano = ($ano) ? "AND year(r.data_vencimento) = '$ano'" : "";
		 $wmes = ($mes) ? "AND DATE_FORMAT(r.data_vencimento, '%m/%Y') = '$mes'" : "";
		 $sql = "SELECT t.tipo, SUM(r.valor) AS valor " 
		  . "\n FROM receita as r " 
		  . "\n LEFT JOIN tipo_pagamento as t on t.id = r.tipo" 
		  . "\n WHERE r.inativo = 0 AND r.tipo > 0 AND r.pago = 1 $wano $wmes $wempresa"
		  . "\n GROUP BY r.tipo";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      } 
	  
	  /**
       * Gestao::getPMV()
       * 
       * @return
       */
      public function getPMV()
      {
		$sql = "SELECT valor_pago, data_pagamento, DATEDIFF(data_pagamento, CURDATE()) as dias " 
			. "\n FROM receita "
			. "\n WHERE inativo = 0 AND data_pagamento > CURDATE()";
		$row = self::$db->fetch_all($sql);
		$total = 0;
		$acumulado = 0;
		$dias = 0;
		if($row) {
			foreach ($row as $exrow) {
				$total += $exrow->valor_pago;
				$acumulado += $exrow->valor_pago * $exrow->dias;
			}
			unset($exrow);
		}
		if($total > 0){
			$dias = round($acumulado / $total);
		}
		return $dias;
      }
	  
	  /**
       * Gestao::getAMR()
       * 
       * @return
       */
      public function getAMR()
      {
		$sql = "SELECT SUM(valor_pago) as total " 
			. "\n FROM receita "
			. "\n WHERE inativo = 0 AND data_pagamento < CURDATE()";
		$row = self::$db->first($sql);
		$total = ($row) ? $row->total : 0;
		$sql = "SELECT valor_pago, data_pagamento, data_pagamento, DATEDIFF(data_pagamento, data_pagamento) as dias " 
			. "\n FROM receita "
			. "\n WHERE pago = 1 AND inativo = 0 AND data_pagamento < CURDATE() AND data_pagamento < data_pagamento";
		$row = self::$db->fetch_all($sql);
		$acumulado = 0;
		$dias = 0;
		if($row) {
			foreach ($row as $exrow) {
				$acumulado += $exrow->valor_pago * $exrow->dias;
			}
			unset($exrow);
		}
		if($total > 0){
			$dias = round($acumulado / $total);
		}
		return $dias;
      }
	  
	  /**
       * Gestao::getInfoDespesas()
       * @return
       */
      public function getInfoDespesas($dataini = 0, $datafim = 0)
      {	
		 $sql = "SELECT SUM(valor) AS valor" 
		  . "\n FROM despesa" 
		  . "\n WHERE pago = 1 AND inativo = 0 AND data_pagamento BETWEEN STR_TO_DATE('$dataini 00:00','%d/%m/%Y %H:%i') AND STR_TO_DATE('$datafim 23:59','%d/%m/%Y %H:%i') ";
		  $row = self::$db->first($sql);

          return ($row) ? $row->valor : 0;
      }
	  
	  /**
       * Gestao::getInfoDespesasPagarTotal()
       * @return
       */
      public function getInfoDespesasPagarTotal($dataini = 0, $datafim = 0)
      {	
		 $sql = "SELECT SUM(valor) AS valor" 
		  . "\n FROM despesa" 
		  . "\n WHERE pago = 0 AND inativo = 0  ";
		  $row = self::$db->first($sql);

          return ($row) ? $row->valor : 0;
      }
	  
	  /**
       * Gestao::getInfoDespesasPagar()
       * @return
       */
      public function getInfoDespesasPagar($dataini = 0, $datafim = 0)
      {	
		 $sql = "SELECT SUM(valor) AS valor" 
		  . "\n FROM despesa" 
		  . "\n WHERE pago = 0 AND inativo = 0 AND data_vencimento BETWEEN STR_TO_DATE('$dataini 00:00','%d/%m/%Y %H:%i') AND STR_TO_DATE('$datafim 23:59','%d/%m/%Y %H:%i') ";
		  $row = self::$db->first($sql);

          return ($row) ? $row->valor : 0;
      }
	  
	  /**
       * Gestao::getInfoReceberTotal()
       * @return
       */
      public function getInfoReceberTotal($dataini = 0, $datafim = 0)
      {	
		 $sql = "SELECT SUM(valor) AS valor" 
		  . "\n FROM receita" 
		  . "\n WHERE pago = 0 AND inativo = 0 ";
		  $row = self::$db->first($sql);

          return ($row) ? $row->valor : 0;
      }
	  
	  /**
       * Gestao::getInfoReceber()
       * @return
       */
      public function getInfoReceber($dataini = 0, $datafim = 0)
      {	
		 $sql = "SELECT SUM(valor) AS valor" 
		  . "\n FROM receita" 
		  . "\n WHERE pago = 0 AND inativo = 0 AND data_pagamento BETWEEN STR_TO_DATE('$dataini 00:00','%d/%m/%Y %H:%i') AND STR_TO_DATE('$datafim 23:59','%d/%m/%Y %H:%i') ";
		  $row = self::$db->first($sql);

          return ($row) ? $row->valor : 0;
      }
	  
	  /**
       * Gestao::getInfoRecebido()
       * @return
       */
      public function getInfoRecebido($dataini = 0, $datafim = 0)
      {	
		 $sql = "SELECT SUM(valor_pago) AS valor" 
		  . "\n FROM receita" 
		  . "\n WHERE pago = 1 AND inativo = 0 AND data_pagamento BETWEEN STR_TO_DATE('$dataini 00:00','%d/%m/%Y %H:%i') AND STR_TO_DATE('$datafim 23:59','%d/%m/%Y %H:%i') ";
		  $row = self::$db->first($sql);

          return ($row) ? $row->valor : 0;
      }
	  
	  /**
       * Gestao::getInfoLigacaoes()
       * 
       * @return
       */
      public function getInfoLigacaoes($dataini = 0, $datafim = 0)
      {	
		  $sql = "SELECT COUNT(1) as quant" 
		  . "\n FROM cadastro_retorno" 
		  . "\n WHERE data BETWEEN STR_TO_DATE('$dataini 00:00','%d/%m/%Y %H:%i') AND STR_TO_DATE('$datafim 23:59','%d/%m/%Y %H:%i') ";
		  $row = self::$db->first($sql);
          return ($row) ? $row->quant : 0;
      }
	  
	  /**
       * Gestao::getInfoLigacaoesConsultor()
       * 
       * @return
       */
      public function getInfoLigacaoesConsultor($consultor = 0, $mes_ano = 0)
      {	
		 $sql = "SELECT COUNT(1) as quant" 
		  . "\n FROM cadastro_retorno" 
		  . "\n WHERE usuario = '$consultor' AND DATE_FORMAT(data, '%d/%m/%Y') = '$mes_ano' ";
		  $row = self::$db->first($sql);
          return ($row) ? $row->quant : 0;
      }
	  
	  /**
       * Gestao::getInfoVisitas()
       * 
       * @return
       */
      public function getInfoVisitas($dataini = 0, $datafim = 0)
      {	
		  $sql = "SELECT COUNT(1) as quant" 
		  . "\n FROM cadastro_retorno" 
		  . "\n WHERE id_status = 5 AND data BETWEEN STR_TO_DATE('$dataini 00:00','%d/%m/%Y %H:%i') AND STR_TO_DATE('$datafim 23:59','%d/%m/%Y %H:%i') ";
		  $row = self::$db->first($sql);
          return ($row) ? $row->quant : 0;
      }
	  
	  /**
       * Gestao::getInfoVisitasConsultor()
       * 
       * @return
       */
      public function getInfoVisitasConsultor($consultor = 0, $mes_ano = 0)
      {	
		  $sql = "SELECT COUNT(1) as quant" 
		  . "\n FROM cadastro_retorno" 
		  . "\n WHERE id_status = 5 AND usuario = '$consultor' AND DATE_FORMAT(data, '%d/%m/%Y') = '$mes_ano' ";
		  $row = self::$db->first($sql);
          return ($row) ? $row->quant : 0;
      }
	  
	  /**
       * Gestao::getInfoAgendas()
       * 
       * @return
       */
      public function getInfoAgendas($dataini = 0, $datafim = 0)
      {	
		  $sql = "SELECT COUNT(1) as quant" 
		  . "\n FROM cadastro_retorno" 
		  . "\n WHERE id_status = 4 AND data BETWEEN STR_TO_DATE('$dataini 00:00','%d/%m/%Y %H:%i') AND STR_TO_DATE('$datafim 23:59','%d/%m/%Y %H:%i') ";
		  $row = self::$db->first($sql);
          return ($row) ? $row->quant : 0;
      }
	  
	  /**
       * Gestao::getInfoAgendasConsultor()
       * 
       * @return
       */
      public function getInfoAgendasConsultor($consultor = 0, $mes_ano = 0)
      {	
		  $sql = "SELECT COUNT(1) as quant" 
		  . "\n FROM cadastro_retorno" 
		  . "\n WHERE id_status = 4 AND usuario = '$consultor' AND DATE_FORMAT(data, '%d/%m/%Y') = '$mes_ano' ";
		  $row = self::$db->first($sql);
          return ($row) ? $row->quant : 0;
      }
	  
	  /**
       * Gestao::getInfoAgendasConsultor()
       * 
       * @return
       */
      public function getInfoAgendasProgramadaConsultor($consultor = 0, $mes_ano = 0)
      {	
		  $sql = "SELECT COUNT(1) as quant" 
		  . "\n FROM cadastro_retorno" 
		  . "\n WHERE id_status = 4 AND usuario = '$consultor' AND DATE_FORMAT(data_retorno, '%d/%m/%Y') = '$mes_ano' ";
		  $row = self::$db->first($sql);
          return ($row) ? $row->quant : 0;
      }
	  
	  /**
       * Gestao::getInfoRetornoProgramado()
       * 
       * @return
       */
      public function getInfoRetornoProgramado($consultor = 0)
      {	
		  $sql = "SELECT COUNT(1) as quant" 
		  . "\n FROM cadastro_retorno" 
		  . "\n WHERE ativo = 1 AND usuario = '$consultor' AND data_retorno > CURDATE()";
		  $row = self::$db->first($sql);
          return ($row) ? $row->quant : 0;
      }
	  
	  /**
       * Gestao::getInfoRetornoVazio()
       * 
       * @return
       */
      public function getInfoRetornoVazio($consultor = 0)
      {	
		  $sql = "SELECT COUNT(1) as quant" 
		  . "\n FROM cadastro_retorno" 
		  . "\n WHERE ativo = 1 AND usuario = '$consultor' AND DATE_FORMAT(data_retorno, '%m/%Y') = '00/0000' ";
		  $row = self::$db->first($sql);
          return ($row) ? $row->quant : 0;
      }
	  
	  /**
       * Gestao::getInfoRetornoVazio()
       * 
       * @return
       */
      public function getInfoRetornoVencido($consultor = 0)
      {	
		  $sql = "SELECT COUNT(1) as quant" 
		  . "\n FROM cadastro_retorno" 
		  . "\n WHERE ativo = 1 AND usuario = '$consultor' AND DATE_FORMAT(data_retorno, '%m/%Y') <> '00/0000' AND data_retorno < CURDATE()";
		  $row = self::$db->first($sql);
          return ($row) ? $row->quant : 0;
      }

      /**
       * Gestao::getInfoNovoContato()
       * 
       * @return
       */
      public function getInfoNovoContato($consultor = 0)
      {
         $sql = "SELECT COUNT(1) as quant"  
		  . "\n FROM cadastro"
		  . "\n WHERE usuario = '$consultor' AND id_status = 1 ";
          $row = self::$db->first($sql);
          return ($row) ? $row->quant : 0;
      }
	  
	  /**
       * Gestao::getDREReceitaMensal()
       * 
       * @return
       */
      public function getDREReceitaMensal($mes_ano = 0, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		  $sql = "SELECT c.id_pai, p.conta AS conta_pai, SUM(r.valor_pago) as total " 
		  . "\n FROM conta AS c" 
		  . "\n LEFT JOIN conta AS p ON p.id = c.id_pai" 
		  . "\n LEFT JOIN receita AS r ON c.id = r.id_conta AND r.inativo = 0 " 
		  . "\n 	$wempresa " 
		  . "\n 	AND r.pago = 1 " 
		  . "\n 	AND DATE_FORMAT(r.data_pagamento, '%m/%Y') = '$mes_ano' "
		  . "\n WHERE  c.id_pai IS NOT NULL AND c.tipo = 'C' AND p.dre = 1 AND c.dre = 1 " 
		  . "\n GROUP BY c.id_pai " 
		  . "\n ORDER BY p.ordem, p.conta ASC ";
		  
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
	  }
	  
	  /**
       * Gestao::getDREReceitaMensalTotal()
       * 
       * @return
       */
      public function getDREReceitaMensalTotal($mes_ano = 0, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		  $sql = "SELECT SUM(r.valor_pago) as total " 
		  . "\n FROM receita AS r" 
		  . "\n WHERE r.inativo = 0 " 
		  . "\n 	$wempresa " 
		  . "\n 	AND r.pago = 1 " 
		  . "\n 	AND DATE_FORMAT(r.data_pagamento, '%m/%Y') = '$mes_ano' ";
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
	  }
	  
	  /**
       * Gestao::getDREDespesaMensal()
       * 
       * @return
       */
      public function getDREDespesaMensal($mes_ano = 0, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND d.id_empresa = $id_empresa" : "";
		  $sql = "SELECT c.id_pai, p.conta AS conta_pai, SUM(d.valor_pago) as total " 
		  . "\n FROM conta AS c" 
		  . "\n LEFT JOIN conta AS p ON p.id = c.id_pai" 
		  . "\n LEFT JOIN despesa AS d ON c.id = d.id_conta AND d.inativo = 0 " 
		  . "\n 	$wempresa " 
		  . "\n 	AND d.pago = 1 " 
		  . "\n 	AND DATE_FORMAT(d.data_pagamento, '%m/%Y') = '$mes_ano' " 
		  . "\n WHERE  c.id_pai IS NOT NULL AND c.tipo = 'D' AND p.dre = 1 AND c.dre = 1 " 
		  . "\n GROUP BY c.id_pai " 
		  . "\n ORDER BY p.ordem, c.ordem ASC ";
		  
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
	  } 
	  
	  /**
       * Gestao::getDREDespesaMensalTotal()
       * 
       * @return
       */
      public function getDREDespesaMensalTotal($mes_ano = 0, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND d.id_empresa = $id_empresa" : "";
		  $sql = "SELECT SUM(d.valor_pago) as total " 
		  . "\n FROM despesa AS d "
		  . "\n WHERE d.inativo = 0 " 
		  . "\n 	$wempresa " 
		  . "\n 	AND d.pago = 1 " 
		  . "\n 	AND DATE_FORMAT(d.data_pagamento, '%m/%Y') = '$mes_ano' ";
		  
		  $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
	  }
	  
	  /**
       * Gestao::getDREDespesaAPagar()
       * 
       * @return
       */
      public function getDREDespesaAPagar($id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND d.id_empresa = $id_empresa" : "";
		  $sql = "SELECT DATE_FORMAT(d.data_vencimento, '%m/%Y') AS mes_ano, SUM(d.valor) as total " 
		  . "\n FROM despesa AS d "
		  . "\n WHERE d.inativo = 0 " 
		  . "\n 	$wempresa " 
		  . "\n 	AND d.pago = 0 " 
		  . "\n 	AND d.data_vencimento < DATE_ADD(CURDATE(), INTERVAL 2 MONTH) " 
		  . "\n GROUP BY mes_ano "
		  . "\n ORDER BY mes_ano ";
		  
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
	  }
	  
	  /**
       * Gestao::curvaABCTrimestral()
       * 
       * @return
       */
      public function curvaABCTrimestral($order = 'faturamento')
      {
		 $sql = "SELECT * " 
		  . "\n FROM curva_abc_trimestral" 
		  . "\n ORDER BY $order DESC";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      } 
	  
	  /**
       * Gestao::curvaABCTrimestral()
       * 
       * @return
       */
      public function curvaABCAnual($order = 'faturamento')
      {
		 $sql = "SELECT * " 
		  . "\n FROM curva_abc_anual" 
		  . "\n ORDER BY $order DESC";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      } 
	  
	  /**
       * Gestao::curvaABCClientes()
       * 
       * @return
       */
      public function curvaABCProfissional()
      {
		 $sql = "SELECT * " 
		  . "\n FROM curva_abc_medicos" 
		  . "\n ORDER BY faturamento DESC";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      } 
	  
	  /**
       * Gestao::getPeriodoAtendimento()
	   *
       * @return
       */
	  public function getPeriodoAtendimento($dataini, $datafim, $id_empresa = 0)
      {		  
		  $wempresa = ($id_empresa) ? "AND a.id_empresa = $id_empresa" : "";
		  $sql = "SELECT SUM(a.valor_pago) AS valor, COUNT(1) AS quat " 
		  . "\n FROM atendimento as a "
		  . "\n WHERE a.realizado < 9 AND a.bloqueio = 0 AND a.pago > 0 "
		  ."\n AND a.data_agenda BETWEEN STR_TO_DATE('$dataini 00:00:00','%d/%m/%Y %H:%i:%s') AND STR_TO_DATE('$datafim 23:59:59','%d/%m/%Y %H:%i:%s') $wempresa ";
          $row = self::$db->first($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getPeriodoAtendimentoNaoPago()
	   *
       * @return
       */
	  public function getPeriodoAtendimentoNaoPago($dataini, $datafim, $id_empresa = 0)
      {		  
		  $wempresa = ($id_empresa) ? "AND a.id_empresa = $id_empresa" : "";
		  $sql = "SELECT SUM(a.valor_pago) AS valor, COUNT(1) AS quat " 
		  . "\n FROM atendimento as a "
		  . "\n WHERE a.realizado = 1 AND a.pago = 0 "
		  ."\n AND a.data_agenda BETWEEN STR_TO_DATE('$dataini 00:00:00','%d/%m/%Y %H:%i:%s') AND STR_TO_DATE('$datafim 23:59:59','%d/%m/%Y %H:%i:%s') $wempresa ";
          $row = self::$db->first($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Gestao::getMesReceitasPago()
       * 
       * @return
       */
      public function getMesReceitasPago($mes_ano, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		   $sql = "SELECT d.id, d.dia, SUM(r.valor_pago) AS total "
		  ."\n FROM dias AS d"
		  ."\n LEFT JOIN receita AS r ON DATE_FORMAT(r.data_pagamento, '%m/%Y') = '$mes_ano' "
		  ."\n AND r.tipo <> 4 AND r.pago = 1 AND r.inativo = 0 AND d.id = DAY(r.data_pagamento) $wempresa "
		  ."\n LEFT JOIN conta as c ON c.id = r.id_conta" 
		  ."\n WHERE c.dre = 1 OR c.dre IS NULL" 
		  ."\n GROUP BY d.id"
		  ."\n ORDER BY d.id ASC";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Gestao::getMesReceitasPago()
       * 
       * @return
       */
      public function getMesReceitasConvenio($mes_ano, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		   $sql = "SELECT d.id, d.dia, SUM(r.valor_pago) AS total "
		  ."\n FROM dias AS d"
		  ."\n LEFT JOIN receita AS r ON DATE_FORMAT(r.data_pagamento, '%m/%Y') = '$mes_ano' "
		  ."\n AND r.tipo = 4 AND r.pago = 1 AND r.inativo = 0 AND d.id = DAY(r.data_pagamento) $wempresa "
		  ."\n LEFT JOIN conta as c ON c.id = r.id_conta" 
		  ."\n WHERE c.dre = 1 OR c.dre IS NULL" 
		  ."\n GROUP BY d.id"
		  ."\n ORDER BY d.id ASC";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Gestao::getMesReceitasPagar()
       * 
       * @return
       */
      public function getMesReceitasPagar($mes_ano, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		   $sql = "SELECT d.id, d.dia, SUM(r.valor_pago) AS total "
		  ."\n FROM dias AS d"
		  ."\n LEFT JOIN receita AS r ON DATE_FORMAT(r.data_vencimento, '%m/%Y') = '$mes_ano' "
		  ."\n AND r.tipo <> 4 AND r.pago = 0 AND r.inativo = 0 AND d.id = DAY(r.data_vencimento) $wempresa "
		  ."\n LEFT JOIN conta as c ON c.id = r.id_conta" 
		  ."\n WHERE c.dre = 1 OR c.dre IS NULL" 
		  ."\n GROUP BY d.id"
		  ."\n ORDER BY d.id ASC";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Gestao::getMesReceitasConvenioPagar()
       * 
       * @return
       */
      public function getMesReceitasConvenioPagar($mes_ano, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		   $sql = "SELECT d.id, d.dia, SUM(r.valor_pago) AS total "
		  ."\n FROM dias AS d"
		  ."\n LEFT JOIN receita AS r ON DATE_FORMAT(r.data_vencimento, '%m/%Y') = '$mes_ano' "
		  ."\n AND r.tipo = 4 AND r.pago = 0 AND r.inativo = 0 AND d.id = DAY(r.data_vencimento) $wempresa "
		  ."\n LEFT JOIN conta as c ON c.id = r.id_conta" 
		  ."\n WHERE c.dre = 1 OR c.dre IS NULL" 
		  ."\n GROUP BY d.id"
		  ."\n ORDER BY d.id ASC";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Gestao::getMesReceitasVista()
       * 
       * @return
       */
      public function getMesReceitasVista($mes_ano, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		   $sql = "SELECT d.id, d.dia, SUM(r.valor_pago) AS total "
		  ."\n FROM dias AS d"
		  ."\n LEFT JOIN receita AS r ON DATE_FORMAT(r.data_pagamento, '%m/%Y') = '$mes_ano' "
		  ."\n AND r.pago = 1 AND r.inativo = 0 AND d.id = DAY(r.data_pagamento) "
		  ."\n AND DATE_FORMAT(r.data_vencimento, '%m/%Y') = DATE_FORMAT(r.data_pagamento, '%m/%Y')  $wempresa "
		  ."\n LEFT JOIN conta as c ON c.id = r.id_conta" 
		  ."\n WHERE c.dre = 1 OR c.dre IS NULL" 
		  ."\n GROUP BY d.id"
		  ."\n ORDER BY d.id ASC";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Gestao::getMesReceitasPrazo()
       * 
       * @return
       */
      public function getMesReceitasPrazo($mes_ano, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		   $sql = "SELECT d.id, d.dia, SUM(r.valor_pago) AS total "
		  ."\n FROM dias AS d"
		  ."\n LEFT JOIN receita AS r ON DATE_FORMAT(r.data_pagamento, '%m/%Y') = '$mes_ano' "
		  ."\n AND r.pago = 1 AND r.inativo = 0 AND d.id = DAY(r.data_pagamento) "
		  ."\n AND DATE_FORMAT(r.data_vencimento, '%m/%Y') <> DATE_FORMAT(r.data_pagamento, '%m/%Y')  $wempresa "
		  ."\n LEFT JOIN conta as c ON c.id = r.id_conta" 
		  ."\n WHERE c.dre = 1 OR c.dre IS NULL" 
		  ."\n GROUP BY d.id"
		  ."\n ORDER BY d.id ASC";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Gestao::getMesReceitasAtrasada()
       * 
       * @return
       */
      public function getMesReceitasAtrasada($mes_ano, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		   $sql = "SELECT SUM(r.valor_pago) AS total "
		  ."\n FROM receita AS r"
		  ."\n WHERE DATE_FORMAT(r.data_vencimento, '%m/%Y') = '$mes_ano' "
		  ."\n AND r.pago = 0 AND r.inativo = 0 AND r.data_vencimento < CURDATE() $wempresa";
          $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      }

      /**
       * Gestao::getMesDespesasPago()
       * 
       * @return
       */
      public function getMesDespesasPago($mes_ano, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND p.id_empresa = $id_empresa" : "";
		   $sql = "SELECT d.id, d.dia, SUM(p.valor_pago) AS total "
		  ."\n FROM dias AS d"
		  ."\n LEFT JOIN despesa AS p ON DATE_FORMAT(p.data_pagamento, '%m/%Y') = '$mes_ano' "
		  ."\n AND p.pago = 1 AND p.inativo = 0 AND d.id = DAY(p.data_pagamento) $wempresa "
		  ."\n LEFT JOIN conta as c ON c.id = p.id_conta" 
		  ."\n WHERE c.dre = 1 OR c.dre IS NULL" 
		  ."\n GROUP BY d.id"
		  ."\n ORDER BY d.id ASC";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Gestao::getMesDespesasPagar()
       * 
       * @return
       */
      public function getMesDespesasPagar($mes_ano, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND p.id_empresa = $id_empresa" : "";
		   $sql = "SELECT d.id, d.dia, SUM(p.valor_pago) AS total "
		  ."\n FROM dias AS d"
		  ."\n LEFT JOIN despesa AS p ON DATE_FORMAT(p.data_vencimento, '%m/%Y') = '$mes_ano' "
		  ."\n AND p.pago = 0 AND p.inativo = 0 AND d.id = DAY(p.data_vencimento) $wempresa "
		  ."\n GROUP BY d.id"
		  ."\n ORDER BY d.id ASC";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Gestao::getMesDespesasAtrasada()
       * 
       * @return
       */
      public function getMesDespesasAtrasada($mes_ano, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND d.id_empresa = $id_empresa" : "";
		   $sql = "SELECT SUM(d.valor_pago) AS total "
		  ."\n FROM despesa AS d"
		  ."\n WHERE DATE_FORMAT(d.data_vencimento, '%m/%Y') = '$mes_ano' "
		  ."\n AND d.pago = 0 AND d.inativo = 0 AND d.data_vencimento < CURDATE() $wempresa ";
          $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      }

      /**
       * Gestao::getTotalDespesasAtrasada()
       * 
       * @return
       */
      public function getTotalDespesasAtrasada($id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND d.id_empresa = $id_empresa" : "";
		  $sql = "SELECT SUM(d.valor_pago) AS total "
		  ."\n FROM despesa AS d"
		  ."\n WHERE d.pago = 0 AND d.inativo = 0 AND d.data_vencimento < CURDATE() $wempresa ";
          $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      }

      /**
       * Gestao::getPeriodoReceitasPago()
       * 
       * @return
       */
      public function getPeriodoReceitasPago($dataini, $datafim, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		   $sql = "SELECT SUM(r.valor_pago) AS total "
		  ."\n FROM receita AS r"
		  ."\n LEFT JOIN conta as c ON c.id = r.id_conta" 
		  ."\n WHERE r.data_pagamento BETWEEN STR_TO_DATE('$dataini 00:00:00','%d/%m/%Y %H:%i:%s') AND STR_TO_DATE('$datafim 23:59:59','%d/%m/%Y %H:%i:%s') $wempresa "
		  ."\n AND r.tipo <> 4 AND r.pago = 1 AND r.inativo = 0 AND c.dre = 1 ";
          $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      }

      /**
       * Gestao::getPeriodoReceitasConvenioPago()
       * 
       * @return
       */
      public function getPeriodoReceitasConvenioPago($dataini, $datafim, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		   $sql = "SELECT SUM(r.valor_pago) AS total "
		  ."\n FROM receita AS r"
		  ."\n LEFT JOIN conta as c ON c.id = r.id_conta" 
		  ."\n WHERE r.data_pagamento BETWEEN STR_TO_DATE('$dataini 00:00:00','%d/%m/%Y %H:%i:%s') AND STR_TO_DATE('$datafim 23:59:59','%d/%m/%Y %H:%i:%s') $wempresa "
		  ."\n AND r.tipo = 4 AND r.pago = 1 AND r.inativo = 0 AND c.dre = 1 ";
          $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      }

      /**
       * Gestao::getPeriodoReceitasPagar()
       * 
       * @return
       */
      public function getPeriodoReceitasPagar($dataini, $datafim, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		   $sql = "SELECT SUM(r.valor_pago) AS total "
		  ."\n FROM receita AS r"
		  ."\n WHERE r.data_vencimento BETWEEN STR_TO_DATE('$dataini 00:00:00','%d/%m/%Y %H:%i:%s') AND STR_TO_DATE('$datafim 23:59:59','%d/%m/%Y %H:%i:%s') $wempresa "
		  ."\n AND r.tipo <> 4 AND r.pago = 0 AND r.inativo = 0 ";
          $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      }

      /**
       * Gestao::getPeriodoReceitasConvenioPagar()
       * 
       * @return
       */
      public function getPeriodoReceitasConvenioPagar($dataini, $datafim, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND r.id_empresa = $id_empresa" : "";
		   $sql = "SELECT SUM(r.valor_pago) AS total "
		  ."\n FROM receita AS r"
		  ."\n WHERE r.data_vencimento BETWEEN STR_TO_DATE('$dataini 00:00:00','%d/%m/%Y %H:%i:%s') AND STR_TO_DATE('$datafim 23:59:59','%d/%m/%Y %H:%i:%s') $wempresa "
		  ."\n AND r.tipo = 4 AND r.pago = 0 AND r.inativo = 0 ";
          $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      }

      /**
       * Gestao::getPeriodoDespesasPago()
       * 
       * @return
       */
      public function getPeriodoDespesasPago($dataini, $datafim, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND d.id_empresa = $id_empresa" : "";
		 $sql = "SELECT SUM(d.valor_pago) AS total "
		  ."\n FROM despesa AS d"
		  ."\n LEFT JOIN conta as c ON c.id = d.id_conta" 
		  ."\n WHERE d.data_pagamento BETWEEN STR_TO_DATE('$dataini 00:00:00','%d/%m/%Y %H:%i:%s') AND STR_TO_DATE('$datafim 23:59:59','%d/%m/%Y %H:%i:%s') $wempresa "
		  ."\n AND d.pago = 1 AND d.inativo = 0 AND c.dre = 1";
          $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      }

      /**
       * Gestao::getPeriodoDespesasPagar()
       * 
       * @return
       */
      public function getPeriodoDespesasPagar($dataini, $datafim, $id_empresa = 0)
      {
		  $wempresa = ($id_empresa) ? "AND d.id_empresa = $id_empresa" : "";
		   $sql = "SELECT SUM(d.valor_pago) AS total "
		  ."\n FROM despesa AS d"
		  ."\n WHERE d.data_vencimento BETWEEN STR_TO_DATE('$dataini 00:00:00','%d/%m/%Y %H:%i:%s') AND STR_TO_DATE('$datafim 23:59:59','%d/%m/%Y %H:%i:%s') $wempresa "
		  ."\n AND d.pago = 0 AND d.inativo = 0 ";
          $row = self::$db->first($sql);

          return ($row) ? $row->total : 0;
      }

      /**
       * Atendimento::getAgendaColaborador()
	   * REALIZADO = 0 - AGENDADO
	   * REALIZADO = 1 - REALIZADO
	   * REALIZADO = 2 - LIBERADO
	   * REALIZADO = 3 - CONFIRMADO
	   * REALIZADO = 9 - CANCELADO
       * 
       * @return
       */
      public function getAgendaColaborador($data, $id_medico = 0, $id_empresa = false)
      {	
		  $wempresa = ($id_empresa) ? "AND a.id_empresa = $id_empresa" : "";		  
          $sql = "SELECT a.*, u.nome as medico, p.nome as paciente, p.telefone, p.celular, t.procedimento, t.valor, t.valor_cartao, t.valor_repasse AS tabela_repasse, c.nome as convenio "  
		  . "\n FROM atendimento as a" 
		  . "\n LEFT JOIN cadastro AS c ON c.id = a.id_convenio "
		  . "\n LEFT JOIN usuario AS u ON u.id = a.id_medico "
		  . "\n LEFT JOIN paciente AS p ON p.id = a.id_paciente "
		  . "\n LEFT JOIN tabela AS t ON t.id = a.id_tabela "
		  . "\n WHERE DATE_FORMAT(a.data_agenda, '%m/%Y') = '$data' AND a.id_medico = $id_medico AND a.realizado = 1 $wempresa "
		  . "\n ORDER BY a.data_agenda ASC ";
		  
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Atendimento::getAgendaConvenio()
       * 
       * @return
       */
      public function getAgendaConvenio($data, $id_convenio = 0, $id_empresa = false)
      {	
		  $wempresa = ($id_empresa) ? "AND a.id_empresa = $id_empresa" : "";		  
          $sql = "SELECT a.*, u.nome as medico, p.nome as paciente, p.telefone, p.celular, t.procedimento, t.valor, t.valor_cartao, t.valor_repasse AS tabela_repasse, c.nome as convenio "  
		  . "\n FROM atendimento as a" 
		  . "\n LEFT JOIN cadastro AS c ON c.id = a.id_convenio "
		  . "\n LEFT JOIN usuario AS u ON u.id = a.id_medico "
		  . "\n LEFT JOIN paciente AS p ON p.id = a.id_paciente "
		  . "\n LEFT JOIN tabela AS t ON t.id = a.id_tabela "
		  . "\n WHERE DATE_FORMAT(a.data_agenda, '%m/%Y') = '$data' AND a.id_convenio = $id_convenio AND a.realizado = 1 $wempresa "
		  . "\n ORDER BY a.data_agenda ASC ";
		  
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Atendimento::getAgendaProcedimento()
       * 
       * @return
       */
      public function getAgendaProcedimento($data, $id_tabela = 0, $id_empresa = false)
      {	
		  $wempresa = ($id_empresa) ? "AND a.id_empresa = $id_empresa" : "";		  
          $sql = "SELECT a.*, u.nome as medico, p.nome as paciente, p.telefone, p.celular, t.procedimento, t.valor, t.valor_cartao, t.valor_repasse AS tabela_repasse, c.nome as convenio "  
		  . "\n FROM atendimento as a" 
		  . "\n LEFT JOIN cadastro AS c ON c.id = a.id_convenio "
		  . "\n LEFT JOIN usuario AS u ON u.id = a.id_medico "
		  . "\n LEFT JOIN paciente AS p ON p.id = a.id_paciente "
		  . "\n LEFT JOIN tabela AS t ON t.id = a.id_tabela "
		  . "\n WHERE DATE_FORMAT(a.data_agenda, '%m/%Y') = '$data' AND a.id_tabela = $id_tabela AND a.realizado = 1 $wempresa "
		  . "\n ORDER BY a.data_agenda ASC ";
		  
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getPagamentos()
	   *
       * @return
       */
	  public function getPagamentos($data, $id_empresa = false)
      {
		 $wempresa = ($id_empresa) ? "AND f.id_empresa = $id_empresa" : "";
         $sql = "SELECT f.tipo AS id_tipo, t.tipo AS pagamento, SUM(f.valor) AS valor, SUM(f.valor_desconto) AS valor_desconto, SUM(f.valor_pago) AS valor_pago, COUNT(1) AS quant" 
		  . "\n FROM paciente_financeiro as f" 
		  . "\n LEFT JOIN tipo_pagamento as t on t.id = f.tipo" 
		  . "\n WHERE DATE_FORMAT(f.data_pagamento	, '%m/%Y') = '$data' AND f.pago = 1 AND f.inativo = 0 $wempresa "
		  . "\n GROUP BY f.tipo" 
		  . "\n ORDER BY t.tipo" ;
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Atendimento::getAgendaPagamento()
       * 
       * @return
       */
      public function getAgendaPagamento($data, $id_tipo = 0, $id_empresa = false)
      {	
		  $wempresa = ($id_empresa) ? "AND f.id_empresa = $id_empresa" : "";		  
          $sql = "SELECT a.*, u.nome as medico, p.nome as paciente, p.telefone, p.celular, t.procedimento, t.valor, t.valor_cartao, t.valor_repasse AS tabela_repasse, c.nome as convenio "  
		  . "\n FROM paciente_financeiro as f" 
		  . "\n LEFT JOIN atendimento AS a ON f.id = a.id_pagamento "
		  . "\n LEFT JOIN cadastro AS c ON c.id = a.id_convenio "
		  . "\n LEFT JOIN usuario AS u ON u.id = a.id_medico "
		  . "\n LEFT JOIN paciente AS p ON p.id = a.id_paciente "
		  . "\n LEFT JOIN tabela AS t ON t.id = a.id_tabela "
		  . "\n WHERE DATE_FORMAT(f.data_pagamento, '%m/%Y') = '$data' AND f.tipo = $id_tipo AND f.pago = 1 AND f.inativo = 0 $wempresa "
		  . "\n ORDER BY a.data_agenda ASC ";
		  
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getAtendimentosUsuario()
	   *
       * @return
       */
	  public function getAtendimentosUsuario($data, $id_empresa = false)
      {
		 $wempresa = ($id_empresa) ? "AND a.id_empresa = $id_empresa" : "";
         $sql = "SELECT u.nome, a.usuario_agenda, SUM(a.valor_pago) AS valor_tabela, SUM(a.valor_repasse) AS valor_repasse, COUNT(1) AS quant" 
		  . "\n FROM atendimento as a" 
		  . "\n LEFT JOIN usuario AS u ON u.usuario = a.usuario_agenda "
		  . "\n WHERE DATE_FORMAT(a.data_agenda, '%m/%Y') = '$data' AND a.realizado = 1 $wempresa "
		  . "\n GROUP BY a.usuario_agenda" 
		  . "\n ORDER BY u.nome" ;
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Atendimento::getAgendaUsuarios()
       * 
       * @return
       */
      public function getAgendaUsuarios($data, $usuario = '', $id_empresa = false)
      {	
		  $wempresa = ($id_empresa) ? "AND a.id_empresa = $id_empresa" : "";		  
          $sql = "SELECT a.*, u.nome as medico, p.nome as paciente, p.telefone, p.celular, t.procedimento, t.valor, t.valor_cartao, t.valor_repasse AS tabela_repasse, c.nome as convenio "  
		  . "\n FROM atendimento as a" 
		  . "\n LEFT JOIN cadastro AS c ON c.id = a.id_convenio "
		  . "\n LEFT JOIN usuario AS u ON u.id = a.id_medico "
		  . "\n LEFT JOIN paciente AS p ON p.id = a.id_paciente "
		  . "\n LEFT JOIN tabela AS t ON t.id = a.id_tabela "
		  . "\n WHERE DATE_FORMAT(a.data_agenda, '%m/%Y') = '$data' AND a.usuario_agenda = '$usuario' AND a.realizado = 1 $wempresa "
		  . "\n ORDER BY DATE_FORMAT(a.data_agenda, '%d/%m/%Y'), t.procedimento ASC ";
		  
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Atendimento::getAgendaUsuariosProcedimentos()
       * 
       * @return
       */
      public function getAgendaUsuariosProcedimentos($data, $usuario = '', $id_empresa = false)
      {	
		  $wempresa = ($id_empresa) ? "AND a.id_empresa = $id_empresa" : "";		  
          $sql = "SELECT a.id_tabela, t.procedimento, COUNT(1) AS quant, SUM(a.valor_pago) AS valor_pago "  
		  . "\n FROM atendimento as a" 
		  . "\n LEFT JOIN tabela AS t ON t.id = a.id_tabela "
		  . "\n WHERE DATE_FORMAT(a.data_agenda, '%m/%Y') = '$data' AND a.usuario_agenda = '$usuario' AND a.realizado = 1 $wempresa "
		  . "\n GROUP BY a.id_tabela "
		  . "\n ORDER BY t.procedimento ASC ";
		  
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Atendimento::geAgendasMedico()
       * 
       * @return
       */
      public function geAgendasMedico($dataini = 0, $datafim = 0, $id_empresa = false)
      {		  
		  $wempresa = ($id_empresa) ? " AND a.id_empresa = '$id_empresa' " : "";
          $sql = "SELECT u.nome, a.id, a.data_agenda, a.horaini, a.horafim, a.tempo, a.quantidade, TIMEDIFF(a.horafim, a.horaini) AS diferenca, TIME_TO_SEC(TIMEDIFF(a.horafim, a.horaini))/60 AS minutos, FLOOR(TIME_TO_SEC(TIMEDIFF(a.horafim, a.horaini))/60/a.tempo) AS agendas " 
		  . "\n FROM agenda as a "
		  . "\n LEFT JOIN usuario AS u ON u.id = a.id_medico "
		  . "\n WHERE a.data_agenda BETWEEN STR_TO_DATE('$dataini','%d/%m/%Y') AND STR_TO_DATE('$datafim','%d/%m/%Y') $wempresa "
		  . "\n ORDER BY u.nome ASC ";
		  
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Atendimento::geAgendasMedicoTotal()
       * 
       * @return
       */
      public function geAgendasMedicoTotal($dataini = 0, $datafim = 0, $id_empresa = false)
      {		  
		  $wempresa = ($id_empresa) ? " AND a.id_empresa = '$id_empresa' " : "";
          $sql = "SELECT u.nome AS medico, a.id_medico, SUM(IF( a.quantidade > 0 , a.quantidade, (TIME_TO_SEC(TIMEDIFF(a.horafim, a.horaini))/60/a.tempo))) AS agendas " 
		  . "\n FROM agenda as a "
		  . "\n LEFT JOIN usuario AS u ON u.id = a.id_medico "
		  . "\n WHERE a.data_agenda BETWEEN STR_TO_DATE('$dataini','%d/%m/%Y') AND STR_TO_DATE('$datafim','%d/%m/%Y') $wempresa "
		  . "\n GROUP BY u.nome "
		  . "\n ORDER BY u.nome ASC ";
		  
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Atendimento::geAtendimentoMedicoRealizados()
       * 
       * @return
       */
      public function geAtendimentoMedicoRealizados($dataini = 0, $datafim = 0, $id_medico = 0, $id_empresa = false)
      {		  
		  $wempresa = ($id_empresa) ? " AND a.id_empresa = '$id_empresa' " : "";
          $sql = "SELECT COUNT(1) AS quant " 
		  . "\n FROM atendimento as a "
		  . "\n WHERE a.id_medico = $id_medico AND a.realizado = 1 AND a.data_agenda BETWEEN STR_TO_DATE('$dataini','%d/%m/%Y') AND STR_TO_DATE('$datafim','%d/%m/%Y') $wempresa ";
		  
          $row = self::$db->first($sql);

          return ($row) ? $row->quant : 0;
      }

      /**
       * Atendimento::geAtendimentoMedicoBloqueio()
       * 
       * @return
       */
      public function geAtendimentoMedicoBloqueio($dataini = 0, $datafim = 0, $id_medico = 0, $id_empresa = false)
      {		  
		  $wempresa = ($id_empresa) ? " AND a.id_empresa = '$id_empresa' " : "";
          $sql = "SELECT COUNT(1) AS quant " 
		  . "\n FROM atendimento as a "
		  . "\n WHERE a.id_medico = $id_medico AND a.realizado = 0 AND a.bloqueio = 1 AND a.data_agenda BETWEEN STR_TO_DATE('$dataini','%d/%m/%Y') AND STR_TO_DATE('$datafim','%d/%m/%Y') $wempresa ";
		  
          $row = self::$db->first($sql);

          return ($row) ? $row->quant : 0;
      }

      /**
       * Atendimento::geAtendimentoMedicoPendentes()
       * 
       * @return
       */
      public function geAtendimentoMedicoPendentes($dataini = 0, $datafim = 0, $id_medico = 0, $id_empresa = false)
      {		  
		  $wempresa = ($id_empresa) ? " AND a.id_empresa = '$id_empresa' " : "";
          $sql = "SELECT COUNT(1) AS quant " 
		  . "\n FROM atendimento as a "
		  . "\n WHERE a.id_medico = $id_medico AND a.realizado NOT IN (1,9) AND a.bloqueio = 0 AND a.data_agenda BETWEEN STR_TO_DATE('$dataini','%d/%m/%Y') AND STR_TO_DATE('$datafim','%d/%m/%Y') $wempresa ";
		  
          $row = self::$db->first($sql);

          return ($row) ? $row->quant : 0;
      }

      /**
       * Atendimento::geAtendimentoMedicoCancelados()
       * 
       * @return
       */
      public function geAtendimentoMedicoCancelados($dataini = 0, $datafim = 0, $id_medico = 0, $id_empresa = false)
      {		  
		  $wempresa = ($id_empresa) ? " AND a.id_empresa = '$id_empresa' " : "";
          $sql = "SELECT COUNT(1) AS quant " 
		  . "\n FROM atendimento as a "
		  . "\n WHERE a.id_medico = $id_medico AND a.realizado = 9 AND a.bloqueio = 0 AND a.data_agenda BETWEEN STR_TO_DATE('$dataini','%d/%m/%Y') AND STR_TO_DATE('$datafim','%d/%m/%Y') $wempresa ";
		  
          $row = self::$db->first($sql);

          return ($row) ? $row->quant : 0;
      }
	  
      /**
       * Gestao::processarLote()
       * 
       * @return
       */
      public function processarLote()
      {	
		  $id_controle = post('id_controle');
		  $contar = count($id_controle);
		  if($contar == 0)
              Filter::$msgs['contar'] = lang('MSG_ERRO_ADICIONARLOTE');	

          if (empty(Filter::$msgs)) {
			  
			  $id_convenio = post('id_convenio');
			  $id_lote = post('id_lote');
			  if (empty($_POST['id_lote'])) {
				  $data = array(
						'id_empresa' => session('idempresa'), 
						'id_cadastro' => $id_convenio, 
						'data_geracao' => "NOW()",
						'usuario' => session('nomeusuario'),
						'data' => "NOW()"
				  );
				  $id_lote = self::$db->insert("lote", $data);
			  }
			  for ($i=0; $i<$contar; $i++) 
			  {	
					$data_atendimento = array(
						'id_lote' => $id_lote
					);
					self::$db->update("atendimento", $data_atendimento, "id=".$id_controle[$i]);
			  }
			  $this->atualizarLote($id_lote);
			
			if (self::$db->affected()) {				  
				$message = lang('LOTE_ADICIONADO_OK');
				Filter::msgOk($message, "index.php?do=lote&acao=listar");
			  } else Filter::msgAlert(lang('NAOPROCESSADO'));
              
          } else
              print Filter::msgStatus();
      }

      /**
       * Gestao::getLotesRecebidosMensal()
       * 
       * @return
       */
      public function getLotesRecebidosMensal($mes_ano, $id_empresa = false)
      {
		  $wempresa = ($id_empresa) ? "AND l.id_empresa = $id_empresa" : "";
		   $sql = "SELECT d.id, d.dia, SUM(l.valor_pago) AS total "
		  ."\n FROM dias AS d"
		  ."\n LEFT JOIN lote AS l ON DATE_FORMAT(l.data_pagamento, '%m/%Y') = '$mes_ano' "
		  ."\n AND l.pago = 1 AND d.id = DAY(l.data_pagamento) $wempresa "
		  ."\n GROUP BY d.id"
		  ."\n ORDER BY d.id ASC";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getLotes()
       * @return
       */
	  public function getLotes($mes_ano = false, $id_convenio = false)
      {
		  $wconvenio = ($id_convenio) ? " AND l.id_cadastro = '$id_convenio'" : "";
		  $wmes_ano = ($mes_ano) ? " AND DATE_FORMAT(l.data_geracao, '%m/%Y') = '$mes_ano' " : "";
		  $sql = "SELECT l.*, c.nome AS convenio " 
		  . "\n FROM lote as l" 
		  . "\n LEFT JOIN cadastro as c ON c.id = l.id_cadastro" 
		  . "\n WHERE l.inativo = 0 AND l.pago = 0 $wmes_ano $wconvenio "
		  . "\n ORDER BY l.id DESC";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getLotesPagos()
       * @return
       */
	  public function getLotesPagos($mes_ano = false, $id_convenio = false)
      {
		  $wconvenio = ($id_convenio) ? " AND l.id_cadastro = '$id_convenio'" : "";
		  $wmes_ano = ($mes_ano) ? " AND DATE_FORMAT(l.data_pagamento, '%m/%Y') = '$mes_ano' " : "";
		  $sql = "SELECT l.*, c.nome AS convenio " 
		  . "\n FROM lote as l" 
		  . "\n LEFT JOIN cadastro as c ON c.id = l.id_cadastro" 
		  . "\n WHERE l.inativo = 0 AND l.pago = 1 $wmes_ano $wconvenio "
		  . "\n ORDER BY l.id DESC";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getVisualizarLotes()
       * @return
       */
	  public function getVisualizarLotes($id_lote)
      {
          $sql = "SELECT a.id, a.id_convenio, c.nome AS convenio, a.realizado, a.id_tabela, t.procedimento, a.id_medico, u.nome AS medico, a.id_paciente, p.nome AS paciente, a.valor_pago, a.pago_lote, a.data_agenda, DATE_FORMAT(a.data_agenda, '%Y%m%d') as controle " 
		  . "\n FROM atendimento as a "
		  . "\n LEFT JOIN paciente as p ON p.id = a.id_paciente"
		  . "\n LEFT JOIN usuario as u ON u.id = a.id_medico"
		  . "\n LEFT JOIN paciente_financeiro as f ON f.id = a.id_pagamento"
		  . "\n LEFT JOIN tabela as t ON t.id = a.id_tabela"
		  . "\n LEFT JOIN lote as l ON l.id = a.id_lote"
		  . "\n LEFT JOIN cadastro as c ON c.id = a.id_convenio"
		  . "\n WHERE a.realizado = 1 AND a.pago_lote < 2 AND a.id_lote = $id_lote "
		  . "\n ORDER BY a.data_agenda ";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getAdicionarLote()
       * @return
       */
	  public function getAdicionarLote($id_convenio)
      {
          $sql = "SELECT a.id, a.realizado, a.id_tabela, t.procedimento, a.numero_guia, a.autorizacao, a.data_guia, a.usuario_guia, a.id_medico, u.nome AS medico, a.id_paciente, p.nome AS paciente, a.valor_pago, a.pago_lote, a.data_agenda, DATE_FORMAT(a.data_agenda, '%Y%m%d') as controle " 
		  . "\n FROM atendimento as a "
		  . "\n LEFT JOIN tabela as t ON t.id = a.id_tabela"
		  . "\n LEFT JOIN paciente as p ON p.id = a.id_paciente"
		  . "\n LEFT JOIN usuario as u ON u.id = a.id_medico"
		  . "\n LEFT JOIN paciente_financeiro as f ON f.id = a.id_pagamento"
		  . "\n WHERE a.realizadO = 1 AND a.pago_lote = 0 AND a.id_lote = 0 AND a.id_convenio = $id_convenio "
		  . "\n ORDER BY a.data_agenda ";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::atualizarLote()
	   *
       * @return
       */
	  public function atualizarLote($id_lote)
      {
          $sql = "SELECT SUM(a.valor_pago) AS total, COUNT(1) AS quant " 
		  . "\n FROM atendimento as a "
		  . "\n WHERE a.realizado = 1 AND a.id_lote = $id_lote ";
          $row = self::$db->first($sql);
		  if($row and $row->total) {
			  $valor_total = $row->total;
			  $quant = $row->quant;
			  $data = array(
				'valor_total' => $valor_total,
				'valor_pago' => $valor_total,
				'quantidade' => $quant,
				'usuario' => session('nomeusuario'),
				'data' => "NOW()"
			  );
			  self::$db->update("lote", $data, "id=" . $id_lote);
		  }
      }

      /**
       * Gestao::getListaPacientePeriodo()
       * 
       * @return
       */
      public function getListaPacientePeriodo($dataini = 0, $datafim = 0, $id_empresa = false)
      {
		  $wempresa = ($id_empresa) ? " AND a.id_empresa = '$id_empresa' " : "";
          $sql = "SELECT a.*, p.nome as paciente, p.telefone, p.celular, p.cidade, c.nome AS convenio, MAX(a.data_agenda) AS ultima " 
		  . "\n FROM atendimento as a "
		  . "\n LEFT JOIN paciente AS p ON p.id = a.id_paciente "
		  . "\n LEFT JOIN cadastro AS c ON c.id = a.id_convenio "
		  . "\n WHERE a.realizado = 1 AND a.data_agenda BETWEEN STR_TO_DATE('$dataini 00:00','%d/%m/%Y %H:%i') AND STR_TO_DATE('$datafim 23:59','%d/%m/%Y %H:%i') $wempresa "
		  . "\n GROUP BY a.id_paciente "
		  . "\n ORDER BY p.nome ASC ";
		  
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::processarArquivoSlides()
       * 
       * @return
       */
      public function processarArquivoSlides()
      {			  
			if (empty(Filter::$msgs)) {
				print Filter::msgOK(lang('SLIDES_ADICIONADO_ARQUIVO_OK'));				
			} else
              print Filter::msgStatus();
      }
	  
  }
?>